# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CONGEAL_METADATA = Metadata(
    id="f68a7b50f081a50aa62c0826055ec17d488357b5.boutiques",
    name="mris_congeal",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCongealOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_congeal(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType
    """Output surface"""


def mris_congeal(
    input_surface_name: str,
    hemi: str,
    subjects: list[str],
    output_surface_name: str,
    subjects_dir: str | None = None,
    disable_rigid_alignment: bool = False,
    disable_sulc_alignment: bool = False,
    smoothwm_curv: bool = False,
    jacobian_output: str | None = None,
    distance_term: float | None = None,
    manual_label: list[str] | None = None,
    addframe: list[str] | None = None,
    overlay: list[str] | None = None,
    overlay_dir: str | None = None,
    target_subject: bool = False,
    runner: Runner | None = None,
) -> MrisCongealOutputs:
    """
    Program that registers a set of input surfaces together and generates an atlas.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface_name: Input surface name.
        hemi: Hemisphere (hemi).
        subjects: List of subjects.
        output_surface_name: Output surface name.
        subjects_dir: Subjects directory.
        disable_rigid_alignment: Disable initial rigid alignment.
        disable_sulc_alignment: Disable initial sulc alignment.
        smoothwm_curv: Use smoothwm curvature for final alignment.
        jacobian_output: Write-out jacobian overlay data to file.
        distance_term: Specify distance term.
        manual_label: Specify a manual label to align with atlas label.
        addframe: Add frame with specified parameters.
        overlay: Specify overlay surface values and number of averages.
        overlay_dir: Specify overlay directory.
        target_subject: Target specifies a subject's surface, not a template\
            file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCongealOutputs`).
    """
    if manual_label is not None and not (len(manual_label) <= 3): 
        raise ValueError(f"Length of 'manual_label' must be less than 3 but was {len(manual_label)}")
    if addframe is not None and not (len(addframe) <= 4): 
        raise ValueError(f"Length of 'addframe' must be less than 4 but was {len(addframe)}")
    if overlay is not None and not (len(overlay) <= 2): 
        raise ValueError(f"Length of 'overlay' must be less than 2 but was {len(overlay)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CONGEAL_METADATA)
    cargs = []
    cargs.append("mris_congeal")
    cargs.append(input_surface_name)
    cargs.append(hemi)
    cargs.extend(subjects)
    cargs.append(output_surface_name)
    if subjects_dir is not None:
        cargs.extend([
            "-SDIR",
            subjects_dir
        ])
    if disable_rigid_alignment:
        cargs.append("-norot")
    if disable_sulc_alignment:
        cargs.append("-nosulc")
    if smoothwm_curv:
        cargs.append("-curv")
    if jacobian_output is not None:
        cargs.extend([
            "-jacobian",
            jacobian_output
        ])
    if distance_term is not None:
        cargs.extend([
            "-dist",
            str(distance_term)
        ])
    if manual_label is not None:
        cargs.extend([
            "-l",
            *manual_label
        ])
    if addframe is not None:
        cargs.extend([
            "-addframe",
            *addframe
        ])
    if overlay is not None:
        cargs.extend([
            "-overlay",
            *overlay
        ])
    if overlay_dir is not None:
        cargs.extend([
            "-overlay-dir",
            overlay_dir
        ])
    if target_subject:
        cargs.append("-1")
    ret = MrisCongealOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file(output_surface_name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CONGEAL_METADATA",
    "MrisCongealOutputs",
    "mris_congeal",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONNECTED_COMPONENTS_METADATA = Metadata(
    id="415ac7eebb3cd7123aaeb6ad6eb398b6cc1343ba.boutiques",
    name="connected_components",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ConnectedComponentsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `connected_components(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_labelled_image_file: OutputPathType
    """Labeled connected components image output file."""


def connected_components(
    runner: Runner | None = None,
) -> ConnectedComponentsOutputs:
    """
    A tool for identifying connected components in an image.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConnectedComponentsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONNECTED_COMPONENTS_METADATA)
    cargs = []
    cargs.append("connected_components")
    ret = ConnectedComponentsOutputs(
        root=execution.output_file("."),
        output_labelled_image_file=execution.output_file("[OUTPUT_IMAGE].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONNECTED_COMPONENTS_METADATA",
    "ConnectedComponentsOutputs",
    "connected_components",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__QUIET_TALKERS_METADATA = Metadata(
    id="b3ed968e44cf181f4b5122510d5d661ee6ef707c.boutiques",
    name="@Quiet_Talkers",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VQuietTalkersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__quiet_talkers(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__quiet_talkers(
    sudo: bool = False,
    prog: list[str] | None = None,
    npb_val: list[float] | None = None,
    npb_range: list[float] | None = None,
    pif_key: str | None = None,
    no_npb: bool = False,
    list_: bool = False,
    quiet: bool = False,
    runner: Runner | None = None,
) -> VQuietTalkersOutputs:
    """
    A script to find and kill AFNI processes.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        sudo: Invoke higher powers to kill processes that you do not own.
        prog: Instead of the default program list, only kill the specified\
            program. You can use multiple -prog options.
        npb_val: Kill those programs using NIML port block NV.
        npb_range: Kill those using NIML port blocks between NV0 and NV1.
        pif_key: Kill those programs that have a string matching KEY_STRING in\
            their commandline.
        no_npb: Kill any program in the list regardless of -npb options or -pif.
        list_: Just list process numbers, don't run kill command.
        quiet: Do it quietly.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VQuietTalkersOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__QUIET_TALKERS_METADATA)
    cargs = []
    cargs.append("@Quiet_Talkers")
    if sudo:
        cargs.append("-sudo")
    if prog is not None:
        cargs.extend([
            "-prog",
            *prog
        ])
    if npb_val is not None:
        cargs.extend([
            "-npb_val",
            *map(str, npb_val)
        ])
    if npb_range is not None:
        cargs.extend([
            "-npb_range",
            *map(str, npb_range)
        ])
    if pif_key is not None:
        cargs.extend([
            "-pif",
            pif_key
        ])
    if no_npb:
        cargs.append("-no_npb")
    if list_:
        cargs.append("-list")
    if quiet:
        cargs.append("-quiet")
    ret = VQuietTalkersOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VQuietTalkersOutputs",
    "V__QUIET_TALKERS_METADATA",
    "v__quiet_talkers",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_TRANSFORM_METADATA = Metadata(
    id="2cbca47da628de2939f9479c528fef081a7988fd.boutiques",
    name="reg_transform",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cpp2def_output_file: OutputPathType | None
    """File containing the CPP to DEF converted deformation field."""
    comp1_output_file: OutputPathType | None
    """File containing the composed deformation field from two control point
    lattices."""
    comp2_output_file: OutputPathType | None
    """File containing the composed deformation field from a deformation field
    and a control point lattice."""
    comp3_output_file: OutputPathType | None
    """File containing the composed deformation field from two deformation
    fields."""
    def2disp_output_file: OutputPathType | None
    """File containing the converted displacement field from a deformation
    field."""
    disp2def_output_file: OutputPathType | None
    """File containing the converted deformation field from a displacement
    field."""
    upd_sform_output_file: OutputPathType | None
    """File containing the updated image with modified sform."""
    aff2def_output_file: OutputPathType | None
    """File containing the composed deformation field from a non-rigid and an
    affine transformation."""
    inv_affine_output_file: OutputPathType | None
    """File containing the inverted affine matrix."""
    comp_aff_output_file: OutputPathType | None
    """File containing the composed affine matrix."""


def reg_transform(
    reference_image: InputPathType,
    cpp2def_input: InputPathType | None = None,
    cpp2def_output: InputPathType | None = None,
    comp1_cpp2: InputPathType | None = None,
    comp1_cpp1: InputPathType | None = None,
    comp1_output: InputPathType | None = None,
    comp2_cpp: InputPathType | None = None,
    comp2_def: InputPathType | None = None,
    comp2_output: InputPathType | None = None,
    comp3_def2: InputPathType | None = None,
    comp3_def1: InputPathType | None = None,
    comp3_output: InputPathType | None = None,
    def2disp_input: InputPathType | None = None,
    def2disp_output: InputPathType | None = None,
    disp2def_input: InputPathType | None = None,
    disp2def_output: InputPathType | None = None,
    upd_sform_image: InputPathType | None = None,
    upd_sform_affine: InputPathType | None = None,
    upd_sform_output: InputPathType | None = None,
    aff2def_affine: InputPathType | None = None,
    aff2def_target: InputPathType | None = None,
    aff2def_cpp_or_def: InputPathType | None = None,
    aff2def_output: InputPathType | None = None,
    inv_affine_input: InputPathType | None = None,
    inv_affine_output: InputPathType | None = None,
    comp_aff_1st: InputPathType | None = None,
    comp_aff_2nd: InputPathType | None = None,
    comp_aff_output: InputPathType | None = None,
    runner: Runner | None = None,
) -> RegTransformOutputs:
    """
    Tool for performing various transformation operations on medical images
    including control point to deformation conversion, composition of
    transformations, and converting between deformation and displacement fields.
    
    Author: NiftyReg Developers
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        reference_image: Filename of the reference image.
        cpp2def_input: Conversion from control point position to deformation\
            field. Filename of input lattice of control point positions (CPP).
        cpp2def_output: Filename of the output deformation field image (DEF).
        comp1_cpp2: Composition of two lattices of control points.\
            CPP2(CPP1(x)). Filename of lattice of control point that contains the\
            second deformation (CPP2).
        comp1_cpp1: Filename of lattice of control point that contains the\
            initial deformation (CPP1).
        comp1_output: Filename of the output deformation field.
        comp2_cpp: Composition of a deformation field with a lattice of control\
            points. CPP(DEF(x)). Filename of lattice of control point that contains\
            the second deformation (CPP).
        comp2_def: Filename of the deformation field to be used as initial\
            deformation (DEF).
        comp2_output: Filename of the output deformation field.
        comp3_def2: Composition of two deformation fields. DEF2(DEF1(x)).\
            Filename of the second deformation field (DEF2).
        comp3_def1: Filename of the first deformation field (DEF1).
        comp3_output: Filename of the output deformation field.
        def2disp_input: Convert a deformation field into a displacement field.\
            Filename of deformation field x'=T(x).
        def2disp_output: Filename of displacement field x'=x+T(x).
        disp2def_input: Convert a displacement field into a deformation field.\
            Filename of displacement field x'=x+T(x).
        disp2def_output: Filename of deformation field x'=T(x).
        upd_sform_image: Update the sform of a floating (source) image using an\
            affine transformation. Filename of image to be updated.
        upd_sform_affine: Affine transformation defined as Affine x Reference =\
            Floating. Filename of affine transformation.
        upd_sform_output: Updated image filename.
        aff2def_affine: Compose a non-rigid with an affine. Filename of affine\
            transformation.
        aff2def_target: Image used as a target for the non-rigid step.
        aff2def_cpp_or_def: Reference image (B). Filename of control point\
            position or deformation field.
        aff2def_output: Output deformation field filename.
        inv_affine_input: Invert an affine transformation matrix. Filename of\
            input affine matrix.
        inv_affine_output: Filename of inverted affine matrix.
        comp_aff_1st: Compose two affine transformation matrices. Filename of\
            first affine matrix.
        comp_aff_2nd: Filename of second affine matrix.
        comp_aff_output: Filename of composed affine matrix result.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_TRANSFORM_METADATA)
    cargs = []
    cargs.append("reg_transform")
    cargs.extend([
        "-ref",
        execution.input_file(reference_image)
    ])
    if cpp2def_input is not None:
        cargs.extend([
            "-cpp2def",
            execution.input_file(cpp2def_input)
        ])
    if cpp2def_output is not None:
        cargs.append(execution.input_file(cpp2def_output))
    if comp1_cpp2 is not None:
        cargs.extend([
            "-comp1",
            execution.input_file(comp1_cpp2)
        ])
    if comp1_cpp1 is not None:
        cargs.append(execution.input_file(comp1_cpp1))
    if comp1_output is not None:
        cargs.append(execution.input_file(comp1_output))
    if comp2_cpp is not None:
        cargs.extend([
            "-comp2",
            execution.input_file(comp2_cpp)
        ])
    if comp2_def is not None:
        cargs.append(execution.input_file(comp2_def))
    if comp2_output is not None:
        cargs.append(execution.input_file(comp2_output))
    if comp3_def2 is not None:
        cargs.extend([
            "-comp3",
            execution.input_file(comp3_def2)
        ])
    if comp3_def1 is not None:
        cargs.append(execution.input_file(comp3_def1))
    if comp3_output is not None:
        cargs.append(execution.input_file(comp3_output))
    if def2disp_input is not None:
        cargs.extend([
            "-def2disp",
            execution.input_file(def2disp_input)
        ])
    if def2disp_output is not None:
        cargs.append(execution.input_file(def2disp_output))
    if disp2def_input is not None:
        cargs.extend([
            "-disp2def",
            execution.input_file(disp2def_input)
        ])
    if disp2def_output is not None:
        cargs.append(execution.input_file(disp2def_output))
    if upd_sform_image is not None:
        cargs.extend([
            "-updSform",
            execution.input_file(upd_sform_image)
        ])
    if upd_sform_affine is not None:
        cargs.append(execution.input_file(upd_sform_affine))
    if upd_sform_output is not None:
        cargs.append(execution.input_file(upd_sform_output))
    if aff2def_affine is not None:
        cargs.extend([
            "-aff2def",
            execution.input_file(aff2def_affine)
        ])
    if aff2def_target is not None:
        cargs.append(execution.input_file(aff2def_target))
    if aff2def_cpp_or_def is not None:
        cargs.append(execution.input_file(aff2def_cpp_or_def))
    if aff2def_output is not None:
        cargs.append(execution.input_file(aff2def_output))
    if inv_affine_input is not None:
        cargs.extend([
            "-invAffine",
            execution.input_file(inv_affine_input)
        ])
    if inv_affine_output is not None:
        cargs.append(execution.input_file(inv_affine_output))
    if comp_aff_1st is not None:
        cargs.extend([
            "-compAff",
            execution.input_file(comp_aff_1st)
        ])
    if comp_aff_2nd is not None:
        cargs.append(execution.input_file(comp_aff_2nd))
    if comp_aff_output is not None:
        cargs.append(execution.input_file(comp_aff_output))
    ret = RegTransformOutputs(
        root=execution.output_file("."),
        cpp2def_output_file=execution.output_file(pathlib.Path(cpp2def_output).name) if (cpp2def_output is not None) else None,
        comp1_output_file=execution.output_file(pathlib.Path(comp1_output).name) if (comp1_output is not None) else None,
        comp2_output_file=execution.output_file(pathlib.Path(comp2_output).name) if (comp2_output is not None) else None,
        comp3_output_file=execution.output_file(pathlib.Path(comp3_output).name) if (comp3_output is not None) else None,
        def2disp_output_file=execution.output_file(pathlib.Path(def2disp_output).name) if (def2disp_output is not None) else None,
        disp2def_output_file=execution.output_file(pathlib.Path(disp2def_output).name) if (disp2def_output is not None) else None,
        upd_sform_output_file=execution.output_file(pathlib.Path(upd_sform_output).name) if (upd_sform_output is not None) else None,
        aff2def_output_file=execution.output_file(pathlib.Path(aff2def_output).name) if (aff2def_output is not None) else None,
        inv_affine_output_file=execution.output_file(pathlib.Path(inv_affine_output).name) if (inv_affine_output is not None) else None,
        comp_aff_output_file=execution.output_file(pathlib.Path(comp_aff_output).name) if (comp_aff_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_TRANSFORM_METADATA",
    "RegTransformOutputs",
    "reg_transform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_HISTORY_METADATA = Metadata(
    id="3239e5f9ea51e57d7e8c381dfe847271931581c5.boutiques",
    name="afni_history",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniHistoryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_history(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_history(
    verb_level: int | None = None,
    check_date: str | None = None,
    help_: bool = False,
    history: bool = False,
    list_authors: bool = False,
    list_types: bool = False,
    version: bool = False,
    author: str | None = None,
    level: int | None = None,
    min_level: int | None = None,
    program: str | None = None,
    past_entries: int | None = None,
    past_days: int | None = None,
    past_months: int | None = None,
    past_years: int | None = None,
    type_: str | None = None,
    html_: bool = False,
    dline: bool = False,
    reverse: bool = False,
    show_field: str | None = None,
    show_field_names: bool = False,
    runner: Runner | None = None,
) -> AfniHistoryOutputs:
    """
    Show AFNI updates per user, dates, or levels.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        verb_level: Request verbose output (LEVEL is from 0-6).
        check_date: Check history against given date. If most recent\
            afni_history is older than the passed date, the distribution version\
            might be considered out of date.
        help_: Show help information.
        history: Show this program's history.
        list_authors: Show the list of valid authors.
        list_types: Show the list of valid change types.
        version: Show this program's version.
        author: Restrict output to the given author.
        level: Restrict output to the given level.
        min_level: Restrict output to at least level LEVEL.
        program: Restrict output to the given program.
        past_entries: Restrict output to final ENTRIES entries.
        past_days: Restrict output to the past DAYS days.
        past_months: Restrict output to the past MONTHS months.
        past_years: Restrict output to the past YEARS years.
        type_: Restrict output to the given TYPE (TYPE = 0..5, or strings\
            'NEW_PROG', etc.).
        html_: Add HTML formatting.
        dline: Put a divider line between dates.
        reverse: Reverse the sorting order (sort is by date, author, level,\
            program).
        show_field: Restrict entry output to field FIELD. Valid FIELDs include:\
            all, firstline, day, month, year, date, author, program, level, type,\
            desc, verbtext.
        show_field_names: List valid FIELD names for -show_field.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniHistoryOutputs`).
    """
    if verb_level is not None and not (0 <= verb_level <= 6): 
        raise ValueError(f"'verb_level' must be between 0 <= x <= 6 but was {verb_level}")
    if level is not None and not (1 <= level <= 5): 
        raise ValueError(f"'level' must be between 1 <= x <= 5 but was {level}")
    if min_level is not None and not (1 <= min_level <= 5): 
        raise ValueError(f"'min_level' must be between 1 <= x <= 5 but was {min_level}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_HISTORY_METADATA)
    cargs = []
    cargs.append("afni_history")
    if verb_level is not None:
        cargs.extend([
            "-verb",
            str(verb_level)
        ])
    if check_date is not None:
        cargs.extend([
            "-check_date",
            check_date
        ])
    if help_:
        cargs.append("-help")
    if history:
        cargs.append("-hist")
    if list_authors:
        cargs.append("-list_authors")
    if list_types:
        cargs.append("-list_types")
    if version:
        cargs.append("-ver")
    if author is not None:
        cargs.extend([
            "-author",
            author
        ])
    if level is not None:
        cargs.extend([
            "-level",
            str(level)
        ])
    if min_level is not None:
        cargs.extend([
            "-min_level",
            str(min_level)
        ])
    if program is not None:
        cargs.extend([
            "-program",
            program
        ])
    if past_entries is not None:
        cargs.extend([
            "-past_entries",
            str(past_entries)
        ])
    if past_days is not None:
        cargs.extend([
            "-past_days",
            str(past_days)
        ])
    if past_months is not None:
        cargs.extend([
            "-past_months",
            str(past_months)
        ])
    if past_years is not None:
        cargs.extend([
            "-past_years",
            str(past_years)
        ])
    if type_ is not None:
        cargs.extend([
            "-type",
            type_
        ])
    if html_:
        cargs.append("-html")
    if dline:
        cargs.append("-dline")
    if reverse:
        cargs.append("-reverse")
    if show_field is not None:
        cargs.extend([
            "-show_field",
            show_field
        ])
    if show_field_names:
        cargs.append("-show_field_names")
    ret = AfniHistoryOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_HISTORY_METADATA",
    "AfniHistoryOutputs",
    "afni_history",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_EXTRACT_SURFACE_MEASUREMENTS_METADATA = Metadata(
    id="1571ae7852c5d0ff3bb69988315d8db4d363f2a7.boutiques",
    name="dmri_extractSurfaceMeasurements",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriExtractSurfaceMeasurementsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_extract_surface_measurements(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_extract_surface_measurements(
    streamline_file: InputPathType,
    lh_surface_file: InputPathType,
    lh_thickness_overlay: InputPathType,
    lh_curvature_overlay: InputPathType,
    rh_surface_file: InputPathType,
    rh_thickness_overlay: InputPathType,
    rh_curvature_overlay: InputPathType,
    output_directory: str,
    reference_image: InputPathType | None = None,
    reference_image_anatomical: InputPathType | None = None,
    transformation: InputPathType | None = None,
    annotation_file: InputPathType | None = None,
    fa_options: list[str] | None = None,
    runner: Runner | None = None,
) -> DmriExtractSurfaceMeasurementsOutputs:
    """
    A tool for extracting surface measurements from diffusion MRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        streamline_file: Streamline file in .trk format.
        lh_surface_file: Left hemisphere surface file.
        lh_thickness_overlay: Left hemisphere thickness overlay file.
        lh_curvature_overlay: Left hemisphere curvature overlay file.
        rh_surface_file: Right hemisphere surface file.
        rh_thickness_overlay: Right hemisphere thickness overlay file.
        rh_curvature_overlay: Right hemisphere curvature overlay file.
        output_directory: Output directory.
        reference_image: Reference image for situations where FA is not used.
        reference_image_anatomical: Reference image for anatomical space when\
            diffusion and anatomical spaces are not registered.
        transformation: Transformation from diffusion to anatomical space.
        annotation_file: Annotation file.
        fa_options: FA options including the number of files and their\
            respective paths.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriExtractSurfaceMeasurementsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_EXTRACT_SURFACE_MEASUREMENTS_METADATA)
    cargs = []
    cargs.append("dmri_extractSurfaceMeasurements")
    cargs.extend([
        "-i",
        execution.input_file(streamline_file)
    ])
    cargs.extend([
        "-sl",
        execution.input_file(lh_surface_file)
    ])
    cargs.extend([
        "-tl",
        execution.input_file(lh_thickness_overlay)
    ])
    cargs.extend([
        "-cl",
        execution.input_file(lh_curvature_overlay)
    ])
    cargs.extend([
        "-sr",
        execution.input_file(rh_surface_file)
    ])
    cargs.extend([
        "-tr",
        execution.input_file(rh_thickness_overlay)
    ])
    cargs.extend([
        "-cr",
        execution.input_file(rh_curvature_overlay)
    ])
    cargs.extend([
        "-o",
        output_directory
    ])
    if reference_image is not None:
        cargs.extend([
            "-rid",
            execution.input_file(reference_image)
        ])
    if reference_image_anatomical is not None:
        cargs.extend([
            "-ria",
            execution.input_file(reference_image_anatomical)
        ])
    if transformation is not None:
        cargs.extend([
            "-t",
            execution.input_file(transformation)
        ])
    if annotation_file is not None:
        cargs.extend([
            "-a",
            execution.input_file(annotation_file)
        ])
    if fa_options is not None:
        cargs.extend([
            "-fa",
            *fa_options
        ])
    ret = DmriExtractSurfaceMeasurementsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_EXTRACT_SURFACE_MEASUREMENTS_METADATA",
    "DmriExtractSurfaceMeasurementsOutputs",
    "dmri_extract_surface_measurements",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL2FLAT_METADATA = Metadata(
    id="4324c6b767a12f1782bca11055508c5f21fddd7d.boutiques",
    name="label2flat",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Label2flatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label2flat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_file: OutputPathType
    """The processed output file generated by label2flat."""


def label2flat(
    subject_name: str,
    label_file: InputPathType,
    patch_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> Label2flatOutputs:
    """
    A tool used in FreeSurfer to process labeling and patch files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: The name of the subject.
        label_file: The label file path.
        patch_file: The patch file path.
        output_file: The output file path.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Label2flatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL2FLAT_METADATA)
    cargs = []
    cargs.append("label2flat")
    cargs.append(subject_name)
    cargs.append(execution.input_file(label_file))
    cargs.append(execution.input_file(patch_file))
    cargs.append(output_file)
    ret = Label2flatOutputs(
        root=execution.output_file("."),
        result_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL2FLAT_METADATA",
    "Label2flatOutputs",
    "label2flat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_BRAIN_SYNC_METADATA = Metadata(
    id="5b4873a7460d63bb6ab8b2f718571646d6b0ba3b.boutiques",
    name="3dBrainSync",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dBrainSyncOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_brain_sync(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    qprefix_output: OutputPathType | None
    """Output dataset after orthogonal matrix transformation"""
    pprefix_output: OutputPathType | None
    """Output dataset after permutation transformation"""
    qprefix_sval: OutputPathType | None
    """Singular values from the BC' decomposition"""
    qprefix_qmat: OutputPathType | None
    """Q matrix"""
    pprefix_perm: OutputPathType | None
    """Permutation indexes p(i)"""


def v_3d_brain_sync(
    inset1: InputPathType,
    inset2: InputPathType,
    qprefix: str | None = None,
    pprefix: str | None = None,
    normalize: bool = False,
    mask: InputPathType | None = None,
    verb: bool = False,
    runner: Runner | None = None,
) -> V3dBrainSyncOutputs:
    """
    'Synchronizes' the -inset2 dataset to match the -inset1 dataset, using
    orthogonal or permutation transformation.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        inset1: Reference dataset.
        inset2: Dataset to be matched to the reference dataset.
        qprefix: Specifies the output dataset to be used for the orthogonal\
            matrix transformation.
        pprefix: Specifies the output dataset to be used for the permutation\
            transformation.
        normalize: Normalize the output dataset(s) so that each time series has\
            sum-of-squares = 1.
        mask: Only operate on nonzero voxels in the mask dataset.
        verb: Print some progress reports and auxiliary information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dBrainSyncOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_BRAIN_SYNC_METADATA)
    cargs = []
    cargs.append("3dBrainSync")
    cargs.extend([
        "-inset1",
        execution.input_file(inset1)
    ])
    cargs.extend([
        "-inset2",
        execution.input_file(inset2)
    ])
    if qprefix is not None:
        cargs.extend([
            "-Qprefix",
            qprefix
        ])
    if pprefix is not None:
        cargs.extend([
            "-Pprefix",
            pprefix
        ])
    if normalize:
        cargs.append("-normalize")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if verb:
        cargs.append("-verb")
    ret = V3dBrainSyncOutputs(
        root=execution.output_file("."),
        qprefix_output=execution.output_file(qprefix + ".nii") if (qprefix is not None) else None,
        pprefix_output=execution.output_file(pprefix + ".nii") if (pprefix is not None) else None,
        qprefix_sval=execution.output_file(qprefix + ".sval.1D") if (qprefix is not None) else None,
        qprefix_qmat=execution.output_file(qprefix + ".qmat.1D") if (qprefix is not None) else None,
        pprefix_perm=execution.output_file(pprefix + ".perm.1D") if (pprefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dBrainSyncOutputs",
    "V_3D_BRAIN_SYNC_METADATA",
    "v_3d_brain_sync",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LOCAL_SVD_METADATA = Metadata(
    id="f516773aa7b46fb72ce0ada8217322e26f4ccee2.boutiques",
    name="3dLocalSVD",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLocalSvdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_local_svd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_local_svd(
    input_file: InputPathType,
    output_file: str,
    auto_mask: bool = False,
    mask_file: InputPathType | None = None,
    nbhd: str | None = None,
    polort: str | None = None,
    vnorm: bool = False,
    vproj: float | None = None,
    runner: Runner | None = None,
) -> V3dLocalSvdOutputs:
    """
    Computes the SVD of time series from a neighborhood of each voxel.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Input time series dataset file.
        output_file: Prefix for the output SVD vector result dataset file.
        auto_mask: Create a mask from time series dataset.
        mask_file: Restrict operations to this mask dataset.
        nbhd: Neighborhood for SVD calculation, e.g., 'SPHERE(5)'.
        polort: Detrending option, ['+' means to add trend back].
        vnorm: Normalize data vectors [strongly recommended].
        vproj: Project central data time series onto local SVD subspace of\
            dimension 'ndim'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLocalSvdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LOCAL_SVD_METADATA)
    cargs = []
    cargs.append("3dLocalSVD")
    if auto_mask:
        cargs.append("-automask")
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    if mask_file is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_file)
        ])
    cargs.extend([
        "-prefix",
        output_file
    ])
    if nbhd is not None:
        cargs.extend([
            "-nbhd",
            nbhd
        ])
    if polort is not None:
        cargs.extend([
            "-polort",
            polort
        ])
    if vnorm:
        cargs.append("-vnorm")
    if vproj is not None:
        cargs.extend([
            "-vproj",
            str(vproj)
        ])
    ret = V3dLocalSvdOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLocalSvdOutputs",
    "V_3D_LOCAL_SVD_METADATA",
    "v_3d_local_svd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_MESH_METADATA = Metadata(
    id="aba9dc7cdd5795dd83c2c7deb8fe8088d1965d12.boutiques",
    name="SurfMesh",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfMeshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_mesh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_file: OutputPathType
    """Output surface file"""


def surf_mesh(
    input_surface: str,
    output_surface: str,
    edge_fraction: float,
    surface_volume: InputPathType | None = None,
    one_state: bool = False,
    anatomical_label: bool = False,
    no_volume_registration: bool = False,
    set_env: str | None = None,
    runner: Runner | None = None,
) -> SurfMeshOutputs:
    """
    Surface mesh manipulation tool.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_surface: Input surface file with specified type.
        output_surface: Output surface file with specified type.
        edge_fraction: Fraction of edges to simplify the surface.
        surface_volume: Surface volume file.
        one_state: Make all input surfaces have the same state.
        anatomical_label: Label all input surfaces as anatomically correct.
        no_volume_registration: Ignore any Rotate, Volreg, Tagalign, or\
            WarpDrive transformations present in the Surface Volume.
        set_env: Set environment variable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfMeshOutputs`).
    """
    if not (0 <= edge_fraction <= 1): 
        raise ValueError(f"'edge_fraction' must be between 0 <= x <= 1 but was {edge_fraction}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_MESH_METADATA)
    cargs = []
    cargs.append("SurfMesh")
    cargs.extend([
        "-i_TYPE",
        input_surface
    ])
    cargs.extend([
        "-o_TYPE",
        output_surface
    ])
    cargs.extend([
        "-edges",
        str(edge_fraction)
    ])
    if surface_volume is not None:
        cargs.extend([
            "-sv",
            execution.input_file(surface_volume)
        ])
    if one_state:
        cargs.append("-onestate")
    if anatomical_label:
        cargs.append("-anatomical")
    if no_volume_registration:
        cargs.append("-novolreg")
    if set_env is not None:
        cargs.extend([
            "-setenv",
            set_env
        ])
    ret = SurfMeshOutputs(
        root=execution.output_file("."),
        output_surface_file=execution.output_file(output_surface + ".surface"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_MESH_METADATA",
    "SurfMeshOutputs",
    "surf_mesh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TEXTURE_RUN_LENGTH_FEATURES_METADATA = Metadata(
    id="99c3089b305255bec7d6249a4c2fc94894071c52.boutiques",
    name="TextureRunLengthFeatures",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class TextureRunLengthFeaturesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `texture_run_length_features(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    short_run_emphasis: OutputPathType
    """Output feature: Short Run Emphasis."""
    long_run_emphasis: OutputPathType
    """Output feature: Long Run Emphasis."""
    grey_level_nonuniformity: OutputPathType
    """Output feature: Grey Level Nonuniformity."""
    run_length_nonuniformity: OutputPathType
    """Output feature: Run Length Nonuniformity."""
    low_grey_level_run_emphasis: OutputPathType
    """Output feature: Low Grey Level Run Emphasis."""
    high_grey_level_run_emphasis: OutputPathType
    """Output feature: High Grey Level Run Emphasis."""
    short_run_low_grey_level_emphasis: OutputPathType
    """Output feature: Short Run Low Grey Level Emphasis."""
    short_run_high_grey_level_emphasis: OutputPathType
    """Output feature: Short Run High Grey Level Emphasis."""
    long_run_low_grey_level_emphasis: OutputPathType
    """Output feature: Long Run Low Grey Level Emphasis."""
    long_run_high_grey_level_emphasis: OutputPathType
    """Output feature: Long Run High Grey Level Emphasis."""


def texture_run_length_features(
    image_dimension: int,
    input_image: InputPathType,
    number_of_bins_per_axis: int | None = 256,
    mask_image: InputPathType | None = None,
    mask_label: int | None = 1,
    runner: Runner | None = None,
) -> TextureRunLengthFeaturesOutputs:
    """
    A tool to calculate texture run length features on an input image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the input image.
        input_image: The path to the input image file.
        number_of_bins_per_axis: The number of bins per axis for the histogram.
        mask_image: The path to the mask image file.
        mask_label: The label value in the mask image to be used.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TextureRunLengthFeaturesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TEXTURE_RUN_LENGTH_FEATURES_METADATA)
    cargs = []
    cargs.append("TextureRunLengthFeatures")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_image))
    if number_of_bins_per_axis is not None:
        cargs.append(str(number_of_bins_per_axis))
    if mask_image is not None:
        cargs.append(execution.input_file(mask_image))
    if mask_label is not None:
        cargs.append(str(mask_label))
    ret = TextureRunLengthFeaturesOutputs(
        root=execution.output_file("."),
        short_run_emphasis=execution.output_file("short_run_emphasis.csv"),
        long_run_emphasis=execution.output_file("long_run_emphasis.csv"),
        grey_level_nonuniformity=execution.output_file("grey_level_nonuniformity.csv"),
        run_length_nonuniformity=execution.output_file("run_length_nonuniformity.csv"),
        low_grey_level_run_emphasis=execution.output_file("low_grey_level_run_emphasis.csv"),
        high_grey_level_run_emphasis=execution.output_file("high_grey_level_run_emphasis.csv"),
        short_run_low_grey_level_emphasis=execution.output_file("short_run_low_grey_level_emphasis.csv"),
        short_run_high_grey_level_emphasis=execution.output_file("short_run_high_grey_level_emphasis.csv"),
        long_run_low_grey_level_emphasis=execution.output_file("long_run_low_grey_level_emphasis.csv"),
        long_run_high_grey_level_emphasis=execution.output_file("long_run_high_grey_level_emphasis.csv"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TEXTURE_RUN_LENGTH_FEATURES_METADATA",
    "TextureRunLengthFeaturesOutputs",
    "texture_run_length_features",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CURVATURE2IMAGE_METADATA = Metadata(
    id="39d168b98aa409f7185978cb8e4d30fc3f31b37b.boutiques",
    name="mris_curvature2image",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCurvature2imageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_curvature2image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_overlay_img: OutputPathType
    """Generated overlay image file."""
    output_distance_img: OutputPathType
    """Generated distance image file."""


def mris_curvature2image(
    surface: InputPathType,
    mask: InputPathType,
    output_overlay: str,
    output_distance: str,
    overlay: InputPathType,
    label: InputPathType,
    radius: float,
    invert_flag: bool = False,
    runner: Runner | None = None,
) -> MrisCurvature2imageOutputs:
    """
    Tool to convert surface curvature data to an image using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Input surface file.
        mask: Input mask file.
        output_overlay: Output overlay image file.
        output_distance: Output distance image file.
        overlay: Overlay file.
        label: Label file.
        radius: Radius value for processing.
        invert_flag: Flag to invert the curvature values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCurvature2imageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CURVATURE2IMAGE_METADATA)
    cargs = []
    cargs.append("mris_curvature2image")
    cargs.extend([
        "-s",
        execution.input_file(surface)
    ])
    cargs.extend([
        "-m",
        execution.input_file(mask)
    ])
    cargs.extend([
        "-o",
        output_overlay
    ])
    cargs.extend([
        "-d",
        output_distance
    ])
    cargs.extend([
        "-c",
        execution.input_file(overlay)
    ])
    cargs.extend([
        "-l",
        execution.input_file(label)
    ])
    if invert_flag:
        cargs.append("-inv")
    cargs.extend([
        "-r",
        str(radius)
    ])
    ret = MrisCurvature2imageOutputs(
        root=execution.output_file("."),
        output_overlay_img=execution.output_file(output_overlay),
        output_distance_img=execution.output_file(output_distance),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CURVATURE2IMAGE_METADATA",
    "MrisCurvature2imageOutputs",
    "mris_curvature2image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_SH_METADATA = Metadata(
    id="2a8c1490dc550d5a8ebdcd5a722be9a6d0cb534c.boutiques",
    name="run_segmentSubjectT2_autoEstimateAlveusML.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RunSegmentSubjectT2AutoEstimateAlveusMlShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_segment_subject_t2_auto_estimate_alveus_ml_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def run_segment_subject_t2_auto_estimate_alveus_ml_sh(
    deployed_mcr_root: str,
    arguments: list[str] | None = None,
    runner: Runner | None = None,
) -> RunSegmentSubjectT2AutoEstimateAlveusMlShOutputs:
    """
    Script to run segmentSubjectT2_autoEstimateAlveusML operation. This script
    requires a MATLAB Compiler Runtime (MCR) root directory as input, but help
    output indicates missing library reference for operation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        deployed_mcr_root: Path to the deployed MATLAB Compiler Runtime (MCR)\
            root directory.
        arguments: Arguments for segmenting subject T2 and automatically\
            estimating Alveus using Machine Learning.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunSegmentSubjectT2AutoEstimateAlveusMlShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_SH_METADATA)
    cargs = []
    cargs.append("run_segmentSubjectT2_autoEstimateAlveusML.sh")
    cargs.append(deployed_mcr_root)
    if arguments is not None:
        cargs.extend(arguments)
    ret = RunSegmentSubjectT2AutoEstimateAlveusMlShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_SH_METADATA",
    "RunSegmentSubjectT2AutoEstimateAlveusMlShOutputs",
    "run_segment_subject_t2_auto_estimate_alveus_ml_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SYNTHESIZE_METADATA = Metadata(
    id="f7b287047be218e070a0e814059c1a76d0ae4655.boutiques",
    name="mri_synthesize",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSynthesizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_synthesize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    synthesized_output: OutputPathType
    """The synthesized FLASH acquisition output volume."""


def mri_synthesize(
    tr: float,
    alpha: float,
    te: float,
    t1_volume: InputPathType,
    pd_volume: InputPathType,
    output_volume: str,
    fixed_weight: bool = False,
    runner: Runner | None = None,
) -> MriSynthesizeOutputs:
    """
    This program synthesizes a FLASH acquisition based on previously computed T1/PD
    maps.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        tr: Repetition time (TR) for the synthesis.
        alpha: Flip angle (alpha) in degrees.
        te: Echo time (TE) for the synthesis.
        t1_volume: Path to the T1 volume.
        pd_volume: Path to the PD volume.
        output_volume: Path for the output volume.
        fixed_weight: Use a fixed weighting to generate an output volume with\
            optimal gray/white contrast.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSynthesizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SYNTHESIZE_METADATA)
    cargs = []
    cargs.append("mri_synthesize")
    cargs.append(str(tr))
    cargs.append(str(alpha))
    cargs.append(str(te))
    cargs.append(execution.input_file(t1_volume))
    cargs.append(execution.input_file(pd_volume))
    cargs.append(output_volume)
    if fixed_weight:
        cargs.append("-w")
    ret = MriSynthesizeOutputs(
        root=execution.output_file("."),
        synthesized_output=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SYNTHESIZE_METADATA",
    "MriSynthesizeOutputs",
    "mri_synthesize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_FILL_HOLES_METADATA = Metadata(
    id="38d91cd88583667f26e3c3c5a803f7aabc4c2228.boutiques",
    name="volume-fill-holes",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeFillHolesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_fill_holes(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output ROI volume"""


def volume_fill_holes(
    volume_in: InputPathType,
    volume_out: str,
    runner: Runner | None = None,
) -> VolumeFillHolesOutputs:
    """
    Fill holes in an roi volume.
    
    Finds all face-connected parts that are not included in the ROI, and fills
    all but the largest one with ones.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input ROI volume.
        volume_out: the output ROI volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeFillHolesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_FILL_HOLES_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-fill-holes")
    cargs.append(execution.input_file(volume_in))
    cargs.append(volume_out)
    ret = VolumeFillHolesOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_FILL_HOLES_METADATA",
    "VolumeFillHolesOutputs",
    "volume_fill_holes",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DIFF_FILES_METADATA = Metadata(
    id="edd2d42b0097cf74079def4a47b5ad005afd8f78.boutiques",
    name="@diff.files",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDiffFilesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__diff_files(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__diff_files(
    files: list[str],
    old_dir: str,
    diff_opts: str | None = None,
    diff_prog: str | None = None,
    ignore_missing: bool = False,
    longlist: bool = False,
    save: bool = False,
    show: bool = False,
    xxdiff: bool = False,
    x_flag: bool = False,
    verbosity: float | None = None,
    runner: Runner | None = None,
) -> VDiffFilesOutputs:
    """
    Show file differences (between specified files and those in another directory).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        files: List of files to compare.
        old_dir: Directory containing the files to compare against.
        diff_opts: Add options to diff command (e.g., -w).
        diff_prog: Display diffs using a specified program (e.g., meld, xxdiff).
        ignore_missing: Continue even if files are missing.
        longlist: Run 'ls -l' on both directories instead of listing files.
        save: Create PDFs of diffs.
        show: Show diffs using 'diff'.
        xxdiff: Show diffs using 'xxdiff'.
        x_flag: Implies -xxdiff and -ignore_missing.
        verbosity: Set verbosity level (2 or 3).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDiffFilesOutputs`).
    """
    if verbosity is not None and not (1 <= verbosity <= 3): 
        raise ValueError(f"'verbosity' must be between 1 <= x <= 3 but was {verbosity}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DIFF_FILES_METADATA)
    cargs = []
    cargs.append("@diff.files")
    cargs.extend(files)
    cargs.append(old_dir)
    if diff_opts is not None:
        cargs.extend([
            "-diff_opts",
            diff_opts
        ])
    if diff_prog is not None:
        cargs.extend([
            "-diff_prog",
            diff_prog
        ])
    if ignore_missing:
        cargs.append("-ignore_missing")
    if longlist:
        cargs.append("-longlist")
    if save:
        cargs.append("-save")
    if show:
        cargs.append("-show")
    if xxdiff:
        cargs.append("-xxdiff")
    if x_flag:
        cargs.append("-X")
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    ret = VDiffFilesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDiffFilesOutputs",
    "V__DIFF_FILES_METADATA",
    "v__diff_files",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

HISTO_COMPUTE_JOINT_DENSITY_METADATA = Metadata(
    id="f724dcdabbfe196e5a6d9bc856c3b1b0e765be9b.boutiques",
    name="histo_compute_joint_density",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class HistoComputeJointDensityOutputs(typing.NamedTuple):
    """
    Output object returned when calling `histo_compute_joint_density(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_joint_density: OutputPathType
    """Computed joint density output file"""


def histo_compute_joint_density(
    volume1: InputPathType,
    volume2: InputPathType,
    joint_density_file: str,
    runner: Runner | None = None,
) -> HistoComputeJointDensityOutputs:
    """
    A tool to compute the joint density of two volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        volume1: Input volume 1.
        volume2: Input volume 2.
        joint_density_file: Output joint density file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `HistoComputeJointDensityOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(HISTO_COMPUTE_JOINT_DENSITY_METADATA)
    cargs = []
    cargs.append("histo_compute_joint_density")
    cargs.append(execution.input_file(volume1))
    cargs.append(execution.input_file(volume2))
    cargs.append(joint_density_file)
    ret = HistoComputeJointDensityOutputs(
        root=execution.output_file("."),
        output_joint_density=execution.output_file(joint_density_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "HISTO_COMPUTE_JOINT_DENSITY_METADATA",
    "HistoComputeJointDensityOutputs",
    "histo_compute_joint_density",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VSM_SMOOTH_METADATA = Metadata(
    id="c9910f98cd5b5b7c5c6d2ac12c7a50e16ba9d6d7.boutiques",
    name="vsm-smooth",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class VsmSmoothOutputs(typing.NamedTuple):
    """
    Output object returned when calling `vsm_smooth(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_vsm: OutputPathType
    """The resulting smoothed voxel shift map."""


def vsm_smooth(
    input_file: InputPathType,
    output_file: str,
    fwhm_value: float,
    temp_dir: str,
    runner: Runner | None = None,
) -> VsmSmoothOutputs:
    """
    Implements a masked smoothing in which the input (vsm) is unchanged in voxels
    that have a non-zero value. In voxels with a zero value, the value is replaced
    with vsm smoothed by the given amount. This will likely only change the voxels
    that are near the edge of the non-zero voxels. This is a simple way to
    extrapolate the non-zero voxels beyond their range. This works well for a B0
    distortion correction voxel shift map (vsm), but it can be applied to other
    maps.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input voxel shift map (vsm).
        output_file: Output smoothed voxel shift map.
        fwhm_value: Full width at half maximum for smoothing.
        temp_dir: Directory for temporary files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VsmSmoothOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VSM_SMOOTH_METADATA)
    cargs = []
    cargs.append("vsm-smooth")
    cargs.extend([
        "--i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "--o",
        output_file
    ])
    cargs.extend([
        "--fwhm",
        str(fwhm_value)
    ])
    cargs.extend([
        "--tmpdir",
        temp_dir
    ])
    ret = VsmSmoothOutputs(
        root=execution.output_file("."),
        output_vsm=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSM_SMOOTH_METADATA",
    "VsmSmoothOutputs",
    "vsm_smooth",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SAMSEG_METADATA = Metadata(
    id="1947f646fba1c79e354f5efabbda10d0a11595ce.boutiques",
    name="samseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SamsegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `samseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType
    """Segmentation output file."""
    posteriors_output: OutputPathType
    """Posterior probabilities output file."""
    probabilities_output: OutputPathType
    """Probabilities output file, including post, prior, and likelihood."""
    mesh_output: OutputPathType
    """Mesh output file (if save-mesh is enabled)."""


def samseg(
    input_files: list[InputPathType],
    output_directory: str,
    t1w_files: list[InputPathType] | None = None,
    t2w_files: list[InputPathType] | None = None,
    flair_files: list[InputPathType] | None = None,
    other_modality_files: list[InputPathType] | None = None,
    options_file: InputPathType | None = None,
    dissection_photo_mode: str | None = None,
    save_history: bool = False,
    subject: str | None = None,
    save_posteriors: bool = False,
    save_probabilities: bool = False,
    no_save_warp: bool = False,
    mrf: bool = False,
    no_mrf: bool = False,
    threads: float | None = None,
    atlas_directory: str | None = None,
    gmm_file: InputPathType | None = None,
    no_block_coordinate_descent: bool = False,
    logdomain_costandgradient_calculator: bool = False,
    no_logdomain_costandgradient_calculator: bool = False,
    recon: bool = False,
    fill: bool = False,
    normalization2: bool = False,
    use_t2w: bool = False,
    use_flair: bool = False,
    hires: bool = False,
    subjects_directory: str | None = None,
    pallidum_separate: bool = False,
    stiffness: float | None = None,
    lesion: bool = False,
    lesion_mask_pattern: list[float] | None = None,
    bias_field_smoothing_kernel: float | None = None,
    registration_file: InputPathType | None = None,
    regmat_file: InputPathType | None = None,
    init_lta: InputPathType | None = None,
    reg_only: bool = False,
    save_mesh: bool = False,
    max_iters: float | None = None,
    dice_file: InputPathType | None = None,
    ignore_unknown: bool = False,
    smooth_wm_cortex: float | None = None,
    profile_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> SamsegOutputs:
    """
    SAMSEG (Statistical and Algorithmic Methods for Segmentation) is a tool for
    segmenting neuroimaging data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_files: Input image files, must be in registration with each\
            other.
        output_directory: Output directory where results will be saved.
        t1w_files: T1-weighted input file, causes input to be conformed unless\
            --hires is used.
        t2w_files: T2-weighted input file.
        flair_files: FLAIR-weighted input file.
        other_modality_files: Specific mode input files, each associated with a\
            custom modality name.
        options_file: JSON file for specifying advanced options.
        dissection_photo_mode: Mode for processing 3D reconstructed dissection\
            photos, specifying left/right/both.
        save_history: Turns on saving of processing history.
        subject: Subject identifier, sets output directory to\
            subject/mri/samseg. The first input must be the conformed T1 weighted\
            input.
        save_posteriors: Save posterior probabilities.
        save_probabilities: Save posterior, prior, and likelihood as 3-frame\
            volume for each tissue type.
        no_save_warp: Do not save m3z-style warp.
        mrf: Perform Markov Random Field processing.
        no_mrf: Do not perform Markov Random Field processing.
        threads: Set the number of CPUs to use.
        atlas_directory: Path to the SAMSEG atlas directory.
        gmm_file: Gaussian Mixture Model file.
        no_block_coordinate_descent: Do not use block coordinate descent.
        logdomain_costandgradient_calculator: Use log-domain cost and gradient\
            calculator.
        no_logdomain_costandgradient_calculator: Do not use log-domain cost and\
            gradient calculator.
        recon: Run recon-all.
        fill: Use samseg to create filled.mgz instead of recon-all.
        normalization2: Use samseg to create brain.mgz instead of recon-all\
            (with --recon).
        use_t2w: Use the T2-weighted input when running recon-all.
        use_flair: Use the FLAIR-weighted input when running recon-all.
        hires: Use -hires when running recon-all.
        subjects_directory: Path to the SUBJECTS_DIR.
        pallidum_separate: Move pallidum outside of global white matter class,\
            used for analyzing T2 or FLAIR.
        stiffness: Set mesh stiffness.
        lesion: Turn on lesion segmentation.
        lesion_mask_pattern: Pattern needed when using T2 for lesion mask,\
            e.g., 0 1.
        bias_field_smoothing_kernel: Width of bias field smoothness.
        registration_file: Registration file (LTA or MAT) as output by samseg.
        regmat_file: Same as --reg.
        init_lta: Initial registration LTA file.
        reg_only: Only perform registration.
        save_mesh: Save the mesh, useful for longitudinal analysis.
        max_iters: Maximum number of iterations.
        dice_file: DICE coefficient file for segmentation.
        ignore_unknown: Ignore unknown flags.
        smooth_wm_cortex: Smooth white matter and cortex priors using specified\
            sigma value.
        profile_file: Run using the cProfile Python profiler, with the\
            specified profile file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SamsegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SAMSEG_METADATA)
    cargs = []
    cargs.append("samseg")
    cargs.extend([
        "--i",
        *[execution.input_file(f) for f in input_files]
    ])
    if t1w_files is not None:
        cargs.extend([
            "--t1w",
            *[execution.input_file(f) for f in t1w_files]
        ])
    if t2w_files is not None:
        cargs.extend([
            "--t2w",
            *[execution.input_file(f) for f in t2w_files]
        ])
    if flair_files is not None:
        cargs.extend([
            "--flair",
            *[execution.input_file(f) for f in flair_files]
        ])
    if other_modality_files is not None:
        cargs.extend([
            "--mode",
            *[execution.input_file(f) for f in other_modality_files]
        ])
    cargs.extend([
        "--o",
        output_directory
    ])
    if options_file is not None:
        cargs.extend([
            "--options",
            execution.input_file(options_file)
        ])
    if dissection_photo_mode is not None:
        cargs.extend([
            "--dissection-photo",
            dissection_photo_mode
        ])
    if save_history:
        cargs.append("--history")
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if save_posteriors:
        cargs.append("--save-posteriors")
    if save_probabilities:
        cargs.append("--save-probabilities")
    if no_save_warp:
        cargs.append("--no-save-warp")
    if mrf:
        cargs.append("--mrf")
    if no_mrf:
        cargs.append("--no-mrf")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if atlas_directory is not None:
        cargs.extend([
            "--atlas",
            atlas_directory
        ])
    if gmm_file is not None:
        cargs.extend([
            "--gmm",
            execution.input_file(gmm_file)
        ])
    if no_block_coordinate_descent:
        cargs.append("--no-block-coordinate-descent")
    if logdomain_costandgradient_calculator:
        cargs.append("--logdomain-costandgradient-calculator")
    if no_logdomain_costandgradient_calculator:
        cargs.append("--no-logdomain-costandgradient-calculator")
    if recon:
        cargs.append("--recon")
    if fill:
        cargs.append("--fill")
    if normalization2:
        cargs.append("--normalization2")
    if use_t2w:
        cargs.append("--use-t2w")
    if use_flair:
        cargs.append("--use-flair")
    if hires:
        cargs.append("--hires")
    if subjects_directory is not None:
        cargs.extend([
            "--sd",
            subjects_directory
        ])
    if pallidum_separate:
        cargs.append("--pallidum-separate")
    if stiffness is not None:
        cargs.extend([
            "--stiffness",
            str(stiffness)
        ])
    if lesion:
        cargs.append("--lesion")
    if lesion_mask_pattern is not None:
        cargs.extend([
            "--lesion-mask-pattern",
            *map(str, lesion_mask_pattern)
        ])
    if bias_field_smoothing_kernel is not None:
        cargs.extend([
            "--bias-field-smoothing-kernel",
            str(bias_field_smoothing_kernel)
        ])
    if registration_file is not None:
        cargs.extend([
            "--reg",
            execution.input_file(registration_file)
        ])
    if regmat_file is not None:
        cargs.extend([
            "--regmat",
            execution.input_file(regmat_file)
        ])
    if init_lta is not None:
        cargs.extend([
            "--initlta",
            execution.input_file(init_lta)
        ])
    if reg_only:
        cargs.append("--reg-only")
    if save_mesh:
        cargs.append("--save-mesh")
    if max_iters is not None:
        cargs.extend([
            "--max-iters",
            str(max_iters)
        ])
    if dice_file is not None:
        cargs.extend([
            "--dice",
            execution.input_file(dice_file)
        ])
    if ignore_unknown:
        cargs.append("--ignore-unknown")
    if smooth_wm_cortex is not None:
        cargs.extend([
            "--smooth-wm-cortex",
            str(smooth_wm_cortex)
        ])
    if profile_file is not None:
        cargs.extend([
            "--profile",
            execution.input_file(profile_file)
        ])
    ret = SamsegOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(output_directory + "/seg.mgz"),
        posteriors_output=execution.output_file(output_directory + "/posteriors.mgz"),
        probabilities_output=execution.output_file(output_directory + "/probabilities.mgz"),
        mesh_output=execution.output_file(output_directory + "/mesh.stl"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SAMSEG_METADATA",
    "SamsegOutputs",
    "samseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TEST_ORIENTATION_PLANES_FROM_PARCELLATION_METADATA = Metadata(
    id="4ec44f64124a848bb9ff90699fb3e68885365ff6.boutiques",
    name="testOrientationPlanesFromParcellation",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TestOrientationPlanesFromParcellationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `test_orientation_planes_from_parcellation(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def test_orientation_planes_from_parcellation(
    input_file: InputPathType,
    output_file: str,
    bb_flag: bool = False,
    runner: Runner | None = None,
) -> TestOrientationPlanesFromParcellationOutputs:
    """
    Tests orientation planes from a given parcellation using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file for the parcellation data.
        output_file: Output file for the orientation planes results.
        bb_flag: Flag to use bounding box in the computation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TestOrientationPlanesFromParcellationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TEST_ORIENTATION_PLANES_FROM_PARCELLATION_METADATA)
    cargs = []
    cargs.append("testOrientationPlanesFromParcellation")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        output_file
    ])
    if bb_flag:
        cargs.append("-bb")
    ret = TestOrientationPlanesFromParcellationOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TEST_ORIENTATION_PLANES_FROM_PARCELLATION_METADATA",
    "TestOrientationPlanesFromParcellationOutputs",
    "test_orientation_planes_from_parcellation",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_NL_ALIGN_BINARY_METADATA = Metadata(
    id="ef5528a0517700c40ec5c8c97d382ea8956dfbf8.boutiques",
    name="mri_nl_align_binary",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriNlAlignBinaryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_nl_align_binary(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_warp: OutputPathType
    """Output warp from the alignment process"""


def mri_nl_align_binary(
    source_file: InputPathType,
    target_file: InputPathType,
    warp_file: str,
    runner: Runner | None = None,
) -> MriNlAlignBinaryOutputs:
    """
    Non-linear alignment tool for MRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source_file: Source image file for alignment.
        target_file: Target image file for alignment.
        warp_file: Output warp file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriNlAlignBinaryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_NL_ALIGN_BINARY_METADATA)
    cargs = []
    cargs.append("mri_nl_align_binary")
    cargs.append(execution.input_file(source_file))
    cargs.append(execution.input_file(target_file))
    cargs.append(warp_file)
    ret = MriNlAlignBinaryOutputs(
        root=execution.output_file("."),
        output_warp=execution.output_file(warp_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_NL_ALIGN_BINARY_METADATA",
    "MriNlAlignBinaryOutputs",
    "mri_nl_align_binary",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_LABEL_AREA_METADATA = Metadata(
    id="af4ae64d94b43274563c0c9b58c9131bb1103886.boutiques",
    name="mris_label_area",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisLabelAreaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_label_area(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_label_area(
    subject_name: str,
    hemi: str,
    surf_name: str,
    annot_name: str,
    labels: list[str],
    pct_flag: bool = False,
    log_file: str | None = None,
    brain_vol: str | None = None,
    runner: Runner | None = None,
) -> MrisLabelAreaOutputs:
    """
    Compute the area of specific labels on a surface of a brain hemisphere in
    FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Name of the subject.
        hemi: Hemisphere, typically 'lh' or 'rh'.
        surf_name: Surface name.
        annot_name: Annotation name.
        labels: Labels to calculate area for.
        pct_flag: Compute brain area as a percentage of all brain labels.
        log_file: Log results to file (use %d to include label number).
        brain_vol: Load brain volume and use it to normalize areas.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisLabelAreaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_LABEL_AREA_METADATA)
    cargs = []
    cargs.append("mris_label_area")
    if pct_flag:
        cargs.append("-p")
    if log_file is not None:
        cargs.extend([
            "-l",
            log_file
        ])
    if brain_vol is not None:
        cargs.extend([
            "-b",
            brain_vol
        ])
    cargs.append(subject_name)
    cargs.append(hemi)
    cargs.append(surf_name)
    cargs.append(annot_name)
    cargs.extend(labels)
    ret = MrisLabelAreaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_LABEL_AREA_METADATA",
    "MrisLabelAreaOutputs",
    "mris_label_area",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UNPACK_IMA_TCL_METADATA = Metadata(
    id="f7bb633c8e2fc57cba56d642be005b58715d8346.boutiques",
    name="unpack_ima.tcl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class UnpackImaTclOutputs(typing.NamedTuple):
    """
    Output object returned when calling `unpack_ima_tcl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def unpack_ima_tcl(
    target_dir: str = "~",
    runner: Runner | None = None,
) -> UnpackImaTclOutputs:
    """
    A tool to unpack MRI DICOM .ima files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        target_dir: Target directory to unpack the files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UnpackImaTclOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UNPACK_IMA_TCL_METADATA)
    cargs = []
    cargs.append("unpack_ima.tcl")
    cargs.append(target_dir)
    ret = UnpackImaTclOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UNPACK_IMA_TCL_METADATA",
    "UnpackImaTclOutputs",
    "unpack_ima_tcl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ATTRIBUTE_METADATA = Metadata(
    id="023f5df529fe405d80f04593e71e023c5a458d03.boutiques",
    name="3dAttribute",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAttributeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_attribute(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout: OutputPathType
    """Output of the attribute value"""


def v_3d_attribute(
    aname: str,
    dset: InputPathType,
    all_: bool = False,
    name: bool = False,
    center: bool = False,
    ssep: str | None = None,
    sprep: str | None = None,
    quote: bool = False,
    runner: Runner | None = None,
) -> V3dAttributeOutputs:
    """
    Prints the value of the attribute 'aname' from the header of the dataset 'dset'.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        aname: Attribute name to be printed from the dataset.
        dset: Dataset from which the attribute value will be printed.
        all_: Print all attributes from the dataset.
        name: Include attribute name in the output.
        center: Print the center of volume in RAI coordinates.
        ssep: Use string SSEP as a separator between strings for multiple\
            sub-bricks.
        sprep: Use string SPREP to replace blank space in string attributes.
        quote: Use single quote around each string.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAttributeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ATTRIBUTE_METADATA)
    cargs = []
    cargs.append("3dAttribute")
    if all_:
        cargs.append("-all")
    if name:
        cargs.append("-name")
    if center:
        cargs.append("-center")
    if ssep is not None:
        cargs.extend([
            "-ssep",
            ssep
        ])
    if sprep is not None:
        cargs.extend([
            "-sprep",
            sprep
        ])
    if quote:
        cargs.append("-quote")
    cargs.append(aname)
    cargs.append(execution.input_file(dset))
    ret = V3dAttributeOutputs(
        root=execution.output_file("."),
        stdout=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAttributeOutputs",
    "V_3D_ATTRIBUTE_METADATA",
    "v_3d_attribute",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WARP_TENSOR_IMAGE_MULTI_TRANSFORM_METADATA = Metadata(
    id="14d19d5d0cd63cddc6a5dbd0cf982ba44c0b6d8b.boutiques",
    name="WarpTensorImageMultiTransform",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class WarpTensorImageMultiTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `warp_tensor_image_multi_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType
    """The resultant transformed output image."""


def warp_tensor_image_multi_transform(
    image_dimension: int,
    moving_image: InputPathType,
    output_image: str,
    transforms: list[str],
    reference_image: InputPathType | None = None,
    tightest_bounding_box: bool = False,
    reslice_by_header: bool = False,
    use_nearest_neighbor: bool = False,
    runner: Runner | None = None,
) -> WarpTensorImageMultiTransformOutputs:
    """
    WarpImageMultiTransform is used to apply transformations including affine and
    deformation fields to an image, supporting various interpolation techniques,
    image header reslicing, and compatibility with ANTS-generated transformations.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimensionality of the image (e.g., 2D or 3D).
        moving_image: The moving image that will be transformed.
        output_image: Path for saving the transformed output image.
        transforms: List of transformations to apply, which can include\
            deformation fields or affine transforms.
        reference_image: Reference image for reslicing or defining the\
            transformation domain.
        tightest_bounding_box: Compute the tightest bounding box using all\
            affine transformations.
        reslice_by_header: Use the orientation matrix and origin encoded in the\
            image file header for reslicing.
        use_nearest_neighbor: Use Nearest Neighbor Interpolator for the\
            transformation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WarpTensorImageMultiTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WARP_TENSOR_IMAGE_MULTI_TRANSFORM_METADATA)
    cargs = []
    cargs.append("WarpImageMultiTransform")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(moving_image))
    cargs.append(output_image)
    if reference_image is not None:
        cargs.extend([
            "-R",
            execution.input_file(reference_image)
        ])
    if tightest_bounding_box:
        cargs.append("--tightest-bounding-box")
    if reslice_by_header:
        cargs.append("--reslice-by-header")
    if use_nearest_neighbor:
        cargs.append("--use-NN")
    cargs.extend(transforms)
    ret = WarpTensorImageMultiTransformOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WARP_TENSOR_IMAGE_MULTI_TRANSFORM_METADATA",
    "WarpTensorImageMultiTransformOutputs",
    "warp_tensor_image_multi_transform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_RELABEL_HYPOINTENSITIES_METADATA = Metadata(
    id="fdccbcea8d0b7d6372e7bb2e7e4ef70fd6f7ab26.boutiques",
    name="mri_relabel_hypointensities",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriRelabelHypointensitiesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_relabel_hypointensities(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_aseg_file: OutputPathType
    """The relabeled output aseg file"""


def mri_relabel_hypointensities(
    input_aseg: InputPathType,
    surface_directory: str,
    output_aseg: str,
    runner: Runner | None = None,
) -> MriRelabelHypointensitiesOutputs:
    """
    Tool for relabeling hypointensities in FreeSurfer's aseg files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_aseg: Input aseg file.
        surface_directory: Directory containing surfaces.
        output_aseg: Output aseg file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriRelabelHypointensitiesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_RELABEL_HYPOINTENSITIES_METADATA)
    cargs = []
    cargs.append("mri_relabel_hypointensities")
    cargs.append(execution.input_file(input_aseg))
    cargs.append(surface_directory)
    cargs.append(output_aseg)
    ret = MriRelabelHypointensitiesOutputs(
        root=execution.output_file("."),
        output_aseg_file=execution.output_file(output_aseg),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_RELABEL_HYPOINTENSITIES_METADATA",
    "MriRelabelHypointensitiesOutputs",
    "mri_relabel_hypointensities",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QUICKSPEC_METADATA = Metadata(
    id="0a985ab38a04ef53341c98e04d446660dcd3c0c6.boutiques",
    name="quickspec",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QuickspecOutputs(typing.NamedTuple):
    """
    Output object returned when calling `quickspec(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_specfile: OutputPathType | None
    """The spec file output."""


def quickspec(
    tn: list[str],
    tsn: list[str],
    tsnad: list[str] | None = None,
    tsnadm: list[str] | None = None,
    tsnadl: list[str] | None = None,
    spec: str | None = None,
    help_: bool = False,
    runner: Runner | None = None,
) -> QuickspecOutputs:
    """
    A quick and dirty way of loading a surface into SUMA or command line programs
    using a spec file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        tn: Specify surface type and name.
        tsn: Specify surface type, state, and name.
        tsnad: Specify surface type, state, name, anatomical correctness, and\
            Local Domain Parent.
        tsnadm: Specify surface type, state, name, anatomical correctness,\
            Local Domain Parent, and node marker file.
        tsnadl: Specify surface type, state, name, anatomical correctness,\
            Local Domain Parent, and label dataset file.
        spec: Name of spec file output. Default is quick.spec.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QuickspecOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QUICKSPEC_METADATA)
    cargs = []
    cargs.append("quickspec")
    cargs.extend([
        "-tn",
        *tn
    ])
    cargs.extend([
        "-tsn",
        *tsn
    ])
    if tsnad is not None:
        cargs.extend([
            "-tsnad",
            *tsnad
        ])
    if tsnadm is not None:
        cargs.extend([
            "-tsnadm",
            *tsnadm
        ])
    if tsnadl is not None:
        cargs.extend([
            "-tsnadl",
            *tsnadl
        ])
    if spec is not None:
        cargs.extend([
            "-spec",
            spec
        ])
    if help_:
        cargs.append("-h")
    ret = QuickspecOutputs(
        root=execution.output_file("."),
        out_specfile=execution.output_file(spec) if (spec is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QUICKSPEC_METADATA",
    "QuickspecOutputs",
    "quickspec",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BUILD_AFNI_PY_METADATA = Metadata(
    id="8b01bbfc26acb4a73b16110f6849bc381629f972.boutiques",
    name="build_afni.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class BuildAfniPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `build_afni_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    command_history_file: OutputPathType
    """Command history file"""
    screen_output_history: OutputPathType
    """Screen output history file"""


def build_afni_py(
    build_root: str,
    clean_root: str | None = None,
    git_branch: str | None = None,
    git_tag: str | None = None,
    git_update: str | None = None,
    make_target: str | None = None,
    makefile: str | None = None,
    package: str | None = None,
    prep_only: bool = False,
    run_cmake: str | None = None,
    run_make: str | None = None,
    verbose_level: float | None = None,
    version: bool = False,
    runner: Runner | None = None,
) -> BuildAfniPyOutputs:
    """
    Compile an AFNI package from the git repository.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        build_root: Root directory to use for git and building.
        clean_root: Specify whether to clean up the build_root. Default is yes.
        git_branch: Specify a branch to checkout in git. Default is master.
        git_tag: Specify a tag to checkout in git. Default is LAST_TAG.
        git_update: Specify whether to update git repo. Default is yes.
        make_target: Specify target for make command. Default is itall.
        makefile: Specify an alternate Makefile to build from.
        package: Specify the desired package to build.
        prep_only: Prepare to but do not run (c)make.
        run_cmake: Choose whether to run a cmake build. Default is no.
        run_make: Choose whether to run a make build. Default is yes.
        verbose_level: Set the verbosity level. Default is 1.
        version: Show the current version.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BuildAfniPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BUILD_AFNI_PY_METADATA)
    cargs = []
    cargs.append("build_afni.py")
    cargs.extend([
        "-build_root",
        build_root
    ])
    if clean_root is not None:
        cargs.extend([
            "-clean_root",
            clean_root
        ])
    if git_branch is not None:
        cargs.extend([
            "-git_branch",
            git_branch
        ])
    if git_tag is not None:
        cargs.extend([
            "-git_tag",
            git_tag
        ])
    if git_update is not None:
        cargs.extend([
            "-git_update",
            git_update
        ])
    if make_target is not None:
        cargs.extend([
            "-make_target",
            make_target
        ])
    if makefile is not None:
        cargs.extend([
            "-makefile",
            makefile
        ])
    if package is not None:
        cargs.extend([
            "-package",
            package
        ])
    if prep_only:
        cargs.append("-prep_only")
    if run_cmake is not None:
        cargs.extend([
            "-run_cmake",
            run_cmake
        ])
    if run_make is not None:
        cargs.extend([
            "-run_make",
            run_make
        ])
    if verbose_level is not None:
        cargs.extend([
            "-verb",
            str(verbose_level)
        ])
    if version:
        cargs.append("-ver")
    ret = BuildAfniPyOutputs(
        root=execution.output_file("."),
        command_history_file=execution.output_file(build_root + "/hist_commands.txt"),
        screen_output_history=execution.output_file(build_root + "/screen_output_history.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BUILD_AFNI_PY_METADATA",
    "BuildAfniPyOutputs",
    "build_afni_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SPHERICAL_AVERAGE_METADATA = Metadata(
    id="1428559d3a56abaf727b5871834a354591593a62.boutiques",
    name="mris_spherical_average",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSphericalAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_spherical_average(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_spherical_average(
    which: typing.Literal["coords", "label", "vals", "curv", "area"],
    fname: str,
    hemi: typing.Literal["lh", "rh"],
    spherical_surf: str,
    subjects: list[str],
    output: str,
    summary_statistics: str | None = None,
    runner: Runner | None = None,
) -> MrisSphericalAverageOutputs:
    """
    This tool adds a template into an average surface in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        which: Specifies the type, one of: coords, label, vals, curv, or area.
        fname: Input file name.
        hemi: Hemisphere: one of lh or rh.
        spherical_surf: The spherical surface file.
        subjects: List of subjects.
        output: Output file or directory.
        summary_statistics: Generate summary statistics and write them into\
            sigavg<cond #>-<hemi>.w and sigvar<cond #>-<hemi>.w.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSphericalAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SPHERICAL_AVERAGE_METADATA)
    cargs = []
    cargs.append("mris_spherical_average")
    if summary_statistics is not None:
        cargs.extend([
            "-s",
            summary_statistics
        ])
    cargs.append(which)
    cargs.append(fname)
    cargs.append(hemi)
    cargs.append(spherical_surf)
    cargs.extend(subjects)
    cargs.append(output)
    ret = MrisSphericalAverageOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SPHERICAL_AVERAGE_METADATA",
    "MrisSphericalAverageOutputs",
    "mris_spherical_average",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIM2_METADATA = Metadata(
    id="dc4766ddbc19de164de7f967033e9406b2958bcf.boutiques",
    name="fim2",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class Fim2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `fim2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    activation_magnitudes: OutputPathType | None
    """Activation magnitudes output file"""
    correlation_image: OutputPathType | None
    """Correlation image output file"""
    contrast_to_noise_image: OutputPathType | None
    """Contrast-to-noise image output file"""
    std_deviation_image: OutputPathType | None
    """Standard deviation image output file"""
    ls_fit_coefficients: OutputPathType | None
    """Least squares fit coefficients image files"""
    subtracted_references: OutputPathType | None
    """Subtracted ortho reference time series images"""


def fim2(
    image_files: list[InputPathType],
    pcnt: float | None = None,
    pcthresh: float | None = None,
    im1: int | None = None,
    num: int | None = None,
    non: bool = False,
    coef: float | None = None,
    ort: list[InputPathType] | None = None,
    ideal: list[InputPathType] | None = None,
    polref: int | None = None,
    fimfile: str | None = None,
    corr: bool = False,
    corfile: str | None = None,
    cnrfile: str | None = None,
    sigfile: str | None = None,
    fitfile: str | None = None,
    subort: str | None = None,
    flim: bool = False,
    clean: bool = False,
    clip: bool = False,
    q: bool = False,
    dfspace: bool = False,
    regbase: str | None = None,
    runner: Runner | None = None,
) -> Fim2Outputs:
    """
    Functional Imaging Mapping Tool.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        image_files: Input MRI image files.
        pcnt: Correlation coefficient threshold will be 1 - 0.01 * #.
        pcthresh: Correlation coefficient threshold will be #.
        im1: Index of image file to use as first in time series; default is 1.
        num: Number of images to actually use; default is to use all images.
        non: Turn off default normalization of the output activation image.
        coef: Scaling factor to convert the activation output from floats to\
            short ints.
        ort: Filename of a time series to which the image data will be\
            orthogonalized before correlations are computed.
        ideal: Filename of a time series to which the image data is to be\
            correlated.
        polref: Use polynomials of order 0..# as extra 'orts'; default is 0.
        fimfile: Filename to save activation magnitudes in.
        corr: Indicates to write correlation output to image file\
            'fimfile.CORR'.
        corfile: Filename to save correlation image in.
        cnrfile: Filename to save contrast-to-noise image in.
        sigfile: Filename to save standard deviation image in.
        fitfile: Image files of the least squares fit coefficients of all the\
            -ort and -polref time series.
        subort: Filename of the new timeseries of images with the orts and\
            polrefs subtracted out.
        flim: Write outputs in mrilib 'float' format.
        clean: Output images won't have the +/- 10000 values forced into their\
            corners for scaling purposes.
        clip: Set to zero regions of low intensity in output correlations, etc.
        q: Quiet operation mode.
        dfspace: Use the 'dfspace' filter to register the images spatially\
            before filtering.
        regbase: Read image in file 'fname' as the base image for registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fim2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIM2_METADATA)
    cargs = []
    cargs.append("fim2")
    cargs.extend([execution.input_file(f) for f in image_files])
    if pcnt is not None:
        cargs.extend([
            "-pcnt",
            str(pcnt)
        ])
    if pcthresh is not None:
        cargs.extend([
            "-pcthresh",
            str(pcthresh)
        ])
    if im1 is not None:
        cargs.extend([
            "-im1",
            str(im1)
        ])
    if num is not None:
        cargs.extend([
            "-num",
            str(num)
        ])
    if non:
        cargs.append("-non")
    if coef is not None:
        cargs.extend([
            "-coef",
            str(coef)
        ])
    if ort is not None:
        cargs.extend([
            "-ort",
            *[execution.input_file(f) for f in ort]
        ])
    if ideal is not None:
        cargs.extend([
            "-ideal",
            *[execution.input_file(f) for f in ideal]
        ])
    if polref is not None:
        cargs.extend([
            "-polref",
            str(polref)
        ])
    if fimfile is not None:
        cargs.extend([
            "-fimfile",
            fimfile
        ])
    if corr:
        cargs.append("-corr")
    if corfile is not None:
        cargs.extend([
            "-corfile",
            corfile
        ])
    if cnrfile is not None:
        cargs.extend([
            "-cnrfile",
            cnrfile
        ])
    if sigfile is not None:
        cargs.extend([
            "-sigfile",
            sigfile
        ])
    if fitfile is not None:
        cargs.extend([
            "-fitfile",
            fitfile
        ])
    if subort is not None:
        cargs.extend([
            "-subort",
            subort
        ])
    if flim:
        cargs.append("-flim")
    if clean:
        cargs.append("-clean")
    if clip:
        cargs.append("-clip")
    if q:
        cargs.append("-q")
    if dfspace:
        cargs.append("-dfspace")
    if regbase is not None:
        cargs.extend([
            "-regbase",
            regbase
        ])
    ret = Fim2Outputs(
        root=execution.output_file("."),
        activation_magnitudes=execution.output_file(fimfile) if (fimfile is not None) else None,
        correlation_image=execution.output_file(corfile) if (corfile is not None) else None,
        contrast_to_noise_image=execution.output_file(cnrfile) if (cnrfile is not None) else None,
        std_deviation_image=execution.output_file(sigfile) if (sigfile is not None) else None,
        ls_fit_coefficients=execution.output_file(fitfile) if (fitfile is not None) else None,
        subtracted_references=execution.output_file(subort) if (subort is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIM2_METADATA",
    "Fim2Outputs",
    "fim2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REBASE_TENSOR_IMAGE_METADATA = Metadata(
    id="cb7dc4431e44610b96f7d5021a64651fd63ad535.boutiques",
    name="RebaseTensorImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class RebaseTensorImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rebase_tensor_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    rebased_image: OutputPathType
    """The rebased tensor image."""


def rebase_tensor_image(
    dimension: int,
    infile: InputPathType,
    outfile: InputPathType,
    method: typing.Literal["PHYSICAL", "LOCAL"],
    reference: InputPathType | None = None,
    runner: Runner | None = None,
) -> RebaseTensorImageOutputs:
    """
    Rebase Tensor Image using specified dimensionality and method.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimension: The dimensionality of the input image.
        infile: The input image file.
        outfile: The output image file.
        method: Method of rebasing the tensor image.
        reference: Reference image file (required if PHYSICAL or LOCAL method\
            is chosen).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RebaseTensorImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REBASE_TENSOR_IMAGE_METADATA)
    cargs = []
    cargs.append("RebaseTensorImage")
    cargs.append(str(dimension))
    cargs.append(execution.input_file(infile))
    cargs.append(execution.input_file(outfile))
    cargs.append(method)
    if reference is not None:
        cargs.append(execution.input_file(reference))
    ret = RebaseTensorImageOutputs(
        root=execution.output_file("."),
        rebased_image=execution.output_file(pathlib.Path(outfile).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REBASE_TENSOR_IMAGE_METADATA",
    "RebaseTensorImageOutputs",
    "rebase_tensor_image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ZTOP_METADATA = Metadata(
    id="aaa21f331bdaf4f959165aeb5f8d7c495a9d8f9d.boutiques",
    name="ztop",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class ZtopOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ztop(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def ztop(
    z_score: float,
    tail_flag: bool = False,
    grf_flag: bool = False,
    number_of_resels: float | None = None,
    runner: Runner | None = None,
) -> ZtopOutputs:
    """
    Converts a z-score to a p-value.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        z_score: Input z-score.
        tail_flag: Use 2-tailed conversion (default is 1-tailed).
        grf_flag: Use GRF maximum-height theory instead of Gaussian PDF.
        number_of_resels: Number of resels (resolution elements) for GRF\
            correction.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZtopOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ZTOP_METADATA)
    cargs = []
    cargs.append("ztop")
    cargs.append(str(z_score))
    if tail_flag:
        cargs.append("-2")
    if grf_flag:
        cargs.append("-g")
    if number_of_resels is not None:
        cargs.append(str(number_of_resels))
    ret = ZtopOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ZTOP_METADATA",
    "ZtopOutputs",
    "ztop",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_FWHM_METADATA = Metadata(
    id="3df5d08538916b5e720d481edb2f9270d2c60c51.boutiques",
    name="mris_fwhm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_fwhm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_fwhm(
    input_file: InputPathType,
    subject: str,
    hemi: str,
    output_file: str,
    surf: str | None = None,
    label_file: InputPathType | None = None,
    cortex_flag: bool = False,
    mask_file: InputPathType | None = None,
    x_matrix: InputPathType | None = None,
    detrend_order: float | None = None,
    smooth_only_flag: bool = False,
    no_detrend_flag: bool = False,
    sqr_flag: bool = False,
    sum_file: str | None = None,
    dat_file: str | None = None,
    ar1dat_file: str | None = None,
    ar1vol: str | None = None,
    fwhmmap: str | None = None,
    prune_flag: bool = False,
    no_prune_flag: bool = False,
    out_mask: str | None = None,
    varnorm_flag: bool = False,
    fwhm: float | None = None,
    niters_only: str | None = None,
    sd: str | None = None,
    synth_flag: bool = False,
    synth_frames: float | None = None,
    threads: float | None = None,
    debug_flag: bool = False,
    checkopts_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> MrisFwhmOutputs:
    """
    Smooths surface data and/or estimates FWHM.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input data file.
        subject: Subject whose surface the input is defined on.
        hemi: Hemifield that the input is defined on. Legal values are lh and\
            rh.
        output_file: Output file to save the processed data.
        surf: Surface name to compute AR1 on. Default is white.
        label_file: Label file to be used as a mask.
        cortex_flag: Use hemi.cortex.label as a mask.
        mask_file: Mask file. Compute AR1 only over voxels in the given mask.
        x_matrix: Detrend data with the matrix in x.mat.
        detrend_order: Order of polynomial detrending.
        smooth_only_flag: Only smooth the data, implies --no-detrend.
        no_detrend_flag: Turn off polynomial detrending.
        sqr_flag: Compute square of input before smoothing.
        sum_file: Prints ascii summary to sumfile.
        dat_file: File for FWHM data.
        ar1dat_file: File containing ar1mean and ar1std.
        ar1vol: Save spatial AR1 as an overlay.
        fwhmmap: Save vertex-wise spatial FWHM as an overlay.
        prune_flag: Remove any voxel that is zero in any subject (after any\
            inversion).
        no_prune_flag: Do not prune (default).
        out_mask: File to save the final mask.
        varnorm_flag: Normalize the variance across space within any mask.
        fwhm: Smooth input by the specified FWHM in mm.
        niters_only: File that reports the number of iterations needed to\
            achieve the specified FWHM.
        sd: Subjects directory.
        synth_flag: Synthesize input with white gaussian noise.
        synth_frames: Number of frames for synthesized input.
        threads: Number of threads to use.
        debug_flag: Turn on debugging.
        checkopts_flag: Don't run anything, just check options and exit.
        version_flag: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_FWHM_METADATA)
    cargs = []
    cargs.append("mris_fwhm")
    cargs.extend([
        "--i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "--subject",
        subject
    ])
    cargs.extend([
        "--hemi",
        hemi
    ])
    if surf is not None:
        cargs.extend([
            "--surf",
            surf
        ])
    if label_file is not None:
        cargs.extend([
            "--label",
            execution.input_file(label_file)
        ])
    if cortex_flag:
        cargs.append("--cortex")
    if mask_file is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_file)
        ])
    if x_matrix is not None:
        cargs.extend([
            "--X",
            execution.input_file(x_matrix)
        ])
    if detrend_order is not None:
        cargs.extend([
            "--detrend",
            str(detrend_order)
        ])
    if smooth_only_flag:
        cargs.append("--smooth-only")
    if no_detrend_flag:
        cargs.append("--no-detrend")
    if sqr_flag:
        cargs.append("--sqr")
    if sum_file is not None:
        cargs.extend([
            "--sum",
            sum_file
        ])
    if dat_file is not None:
        cargs.extend([
            "--dat",
            dat_file
        ])
    if ar1dat_file is not None:
        cargs.extend([
            "--ar1dat",
            ar1dat_file
        ])
    if ar1vol is not None:
        cargs.extend([
            "--ar1",
            ar1vol
        ])
    if fwhmmap is not None:
        cargs.extend([
            "--fwhm-map",
            fwhmmap
        ])
    if prune_flag:
        cargs.append("--prune")
    if no_prune_flag:
        cargs.append("--no-prune")
    if out_mask is not None:
        cargs.extend([
            "--out-mask",
            out_mask
        ])
    if varnorm_flag:
        cargs.append("--varnorm")
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            str(fwhm)
        ])
    if niters_only is not None:
        cargs.extend([
            "--niters-only",
            niters_only
        ])
    cargs.extend([
        "--o",
        output_file
    ])
    if sd is not None:
        cargs.extend([
            "--sd",
            sd
        ])
    if synth_flag:
        cargs.append("--synth")
    if synth_frames is not None:
        cargs.extend([
            "--synth-frames",
            str(synth_frames)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if debug_flag:
        cargs.append("--debug")
    if checkopts_flag:
        cargs.append("--checkopts")
    if version_flag:
        cargs.append("--version")
    ret = MrisFwhmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_FWHM_METADATA",
    "MrisFwhmOutputs",
    "mris_fwhm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_CLIP_LEVEL_METADATA = Metadata(
    id="d74c5cd045e053e286d1b5c8e3587d88d871f128.boutiques",
    name="3dClipLevel",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dClipLevelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_clip_level(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_clip_level(
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dClipLevelOutputs:
    """
    Estimates the value at which to clip the anatomical dataset so that background
    regions are set to zero.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input dataset (e.g. dataset.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dClipLevelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_CLIP_LEVEL_METADATA)
    cargs = []
    cargs.append("3dClipLevel")
    cargs.append("[options]")
    cargs.append(execution.input_file(dataset))
    ret = V3dClipLevelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dClipLevelOutputs",
    "V_3D_CLIP_LEVEL_METADATA",
    "v_3d_clip_level",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SIMPLE_SYN_REGISTRATION_METADATA = Metadata(
    id="8bdec8bc3a221887858c098adc61e63838dc3139.boutiques",
    name="simpleSynRegistration",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class SimpleSynRegistrationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `simple_syn_registration(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_image: OutputPathType
    """The output registered image."""
    transform_matrix: OutputPathType
    """The output transformation matrix."""


def simple_syn_registration(
    fixed_image: InputPathType,
    moving_image: InputPathType,
    initial_transform: str,
    output_prefix: str,
    runner: Runner | None = None,
) -> SimpleSynRegistrationOutputs:
    """
    A simple SyN registration tool.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        fixed_image: The fixed image for registration.
        moving_image: The moving image to be registered.
        initial_transform: The initial transform for registration.
        output_prefix: Prefix for the output file name without any extension.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SimpleSynRegistrationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIMPLE_SYN_REGISTRATION_METADATA)
    cargs = []
    cargs.append("simpleSynRegistration")
    cargs.append(execution.input_file(fixed_image) + ",")
    cargs.append(execution.input_file(moving_image) + ",")
    cargs.append(initial_transform + ",")
    cargs.append(output_prefix)
    ret = SimpleSynRegistrationOutputs(
        root=execution.output_file("."),
        registered_image=execution.output_file(output_prefix + "Registered.nii.gz"),
        transform_matrix=execution.output_file(output_prefix + "Transform.mat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SIMPLE_SYN_REGISTRATION_METADATA",
    "SimpleSynRegistrationOutputs",
    "simple_syn_registration",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_TFCE_METADATA = Metadata(
    id="9baf4e0d50cc6f0f392ab929c38e08f04f8b352f.boutiques",
    name="metric-tfce",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class MetricTfcePresmooth:
    """
    smooth the metric before running TFCE.
    """
    kernel: float
    """the size of the gaussian smoothing kernel in mm, as sigma by default"""
    opt_fwhm: bool = False
    """kernel size is FWHM, not sigma"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-presmooth")
        cargs.append(str(self.kernel))
        if self.opt_fwhm:
            cargs.append("-fwhm")
        return cargs


@dataclasses.dataclass
class MetricTfceParameters:
    """
    set parameters for TFCE integral.
    """
    e: float
    """exponent for cluster area (default 1.0)"""
    h: float
    """exponent for threshold value (default 2.0)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-parameters")
        cargs.append(str(self.e))
        cargs.append(str(self.h))
        return cargs


class MetricTfceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_tfce(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_tfce(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    presmooth: MetricTfcePresmooth | None = None,
    opt_roi_roi_metric: InputPathType | None = None,
    parameters: MetricTfceParameters | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> MetricTfceOutputs:
    """
    Do tfce on a metric file.
    
    This command does not do any statistical analysis. Please use something like
    PALM if you are just trying to do statistics on your data.
    
    Threshold-free cluster enhancement is a method to increase the relative
    value of regions that would form clusters in a standard thresholding test.
    This is accomplished by evaluating the integral of:
    
    e(h, p)^E * h^H * dh
    
    at each vertex p, where h ranges from 0 to the maximum value in the data,
    and e(h, p) is the extent of the cluster containing vertex p at threshold h.
    Negative values are similarly enhanced by negating the data, running the
    same process, and negating the result.
    
    When using -presmooth with -corrected-areas, note that it is an approximate
    correction within the smoothing algorithm (the TFCE correction is exact).
    Doing smoothing on individual surfaces before averaging/TFCE is preferred,
    when possible, in order to better tie the smoothing kernel size to the
    original feature size.
    
    The TFCE method is explained in: Smith SM, Nichols TE., "Threshold-free
    cluster enhancement: addressing problems of smoothing, threshold dependence
    and localisation in cluster inference." Neuroimage. 2009 Jan 1;44(1):83-98.
    PMID: 18501637.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to compute on.
        metric_in: the metric to run TFCE on.
        metric_out: the output metric.
        presmooth: smooth the metric before running TFCE.
        opt_roi_roi_metric: select a region of interest to run TFCE on: the\
            area to run TFCE on, as a metric.
        parameters: set parameters for TFCE integral.
        opt_column_column: select a single column: the column number or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricTfceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_TFCE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-tfce")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(metric_in))
    cargs.append(metric_out)
    if presmooth is not None:
        cargs.extend(presmooth.run(execution))
    if opt_roi_roi_metric is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roi_metric)
        ])
    if parameters is not None:
        cargs.extend(parameters.run(execution))
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    if opt_corrected_areas_area_metric is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(opt_corrected_areas_area_metric)
        ])
    ret = MetricTfceOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_TFCE_METADATA",
    "MetricTfceOutputs",
    "MetricTfceParameters",
    "MetricTfcePresmooth",
    "metric_tfce",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CALC_GRAD_PERC_DEV_METADATA = Metadata(
    id="76e8d6c21efe0b0e70c7144ea3347d4476e917aa.boutiques",
    name="calc_grad_perc_dev",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class CalcGradPercDevOutputs(typing.NamedTuple):
    """
    Output object returned when calling `calc_grad_perc_dev(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def calc_grad_perc_dev(
    fullwarp_image: InputPathType,
    out_basename: str,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> CalcGradPercDevOutputs:
    """
    Compute the gradient percent deviation based on a full warp image from
    gradient_unwarp.py.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        fullwarp_image: Full warp image from gradient_unwarp.py.
        out_basename: Output basename.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display the help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CalcGradPercDevOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CALC_GRAD_PERC_DEV_METADATA)
    cargs = []
    cargs.append("calc_grad_perc_dev")
    cargs.extend([
        "--fullwarp",
        execution.input_file(fullwarp_image)
    ])
    cargs.extend([
        "-o,--out",
        out_basename
    ])
    if verbose_flag:
        cargs.append("-v,--verbose")
    if help_flag:
        cargs.append("-h,--help")
    ret = CalcGradPercDevOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CALC_GRAD_PERC_DEV_METADATA",
    "CalcGradPercDevOutputs",
    "calc_grad_perc_dev",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAP_TRACK_ID_METADATA = Metadata(
    id="8a4654eaf53cc77b2cf484e321c0f2ad7ebde3ea.boutiques",
    name="map_TrackID",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MapTrackIdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `map_track_id(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_trk_file: OutputPathType
    """Mapped track file to new space"""


def map_track_id(
    prefix: str,
    in_trk: InputPathType,
    in_map: InputPathType,
    reference: InputPathType,
    verbose: bool = False,
    orig_zero: bool = False,
    line_only_num: bool = False,
    already_inv: bool = False,
    runner: Runner | None = None,
) -> MapTrackIdOutputs:
    """
    Maps the track file (*.trk) output of 3dTrackID to another space using the
    1Dmatrix_save info of 3dAllineate.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Prefix for the output track file.
        in_trk: The name of the *.trk file to be mapped.
        in_map: Single line of matrix values for the transformation.
        reference: 3D data set in the space to which the TRK file is being\
            mapped.
        verbose: Verbose output.
        orig_zero: Put (0,0,0) as the origin in the output *.trk file.
        line_only_num: If your 1D_MATR file is just 12 numbers in a row.
        already_inv: If you have inverted the mapping or use another program\
            than 3dAllineate.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MapTrackIdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAP_TRACK_ID_METADATA)
    cargs = []
    cargs.append("map_TrackID")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-in_trk",
        execution.input_file(in_trk)
    ])
    cargs.extend([
        "-in_map",
        execution.input_file(in_map)
    ])
    cargs.extend([
        "-ref",
        execution.input_file(reference)
    ])
    if verbose:
        cargs.append("-verb")
    if orig_zero:
        cargs.append("-orig_zero")
    if line_only_num:
        cargs.append("-line_only_num")
    if already_inv:
        cargs.append("-already_inv")
    ret = MapTrackIdOutputs(
        root=execution.output_file("."),
        output_trk_file=execution.output_file(prefix + ".trk"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAP_TRACK_ID_METADATA",
    "MapTrackIdOutputs",
    "map_track_id",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IREPIFITVOL_METADATA = Metadata(
    id="a2bd7dc06ae3c68248647867b862df791e5ba76b.boutiques",
    name="irepifitvol",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IrepifitvolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `irepifitvol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fitted_output: OutputPathType
    """The resulting volume file after fitting"""


def irepifitvol(
    input_file: InputPathType,
    output_file: str = "fitted_output",
    runner: Runner | None = None,
) -> IrepifitvolOutputs:
    """
    A tool for 3D volume fitting.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume file for fitting.
        output_file: Output volume file after fitting.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IrepifitvolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IREPIFITVOL_METADATA)
    cargs = []
    cargs.append("irepifitvol")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = IrepifitvolOutputs(
        root=execution.output_file("."),
        fitted_output=execution.output_file(output_file + ".ext"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IREPIFITVOL_METADATA",
    "IrepifitvolOutputs",
    "irepifitvol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SYSTEMNOISE_METADATA = Metadata(
    id="491f1f9d1e77fe875414f044961ce13c20599887.boutiques",
    name="systemnoise",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SystemnoiseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `systemnoise(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_signal_file: OutputPathType
    """Output signal with added system noise"""


def systemnoise(
    input_signal: InputPathType,
    output_signal: InputPathType,
    noise_standard_deviation: float,
    seed: float | None = None,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> SystemnoiseOutputs:
    """
    Tool for adding system noise to a given signal using FSL's utilities.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_signal: Input signal (possum output matrix).
        output_signal: Output signal (possum matrix form).
        noise_standard_deviation: Set noise standard deviation (units of\
            intensity).
        seed: Input seed value for the sequence.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SystemnoiseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SYSTEMNOISE_METADATA)
    cargs = []
    cargs.append("systemnoise")
    cargs.extend([
        "--in",
        execution.input_file(input_signal)
    ])
    cargs.extend([
        "--out",
        execution.input_file(output_signal)
    ])
    cargs.extend([
        "--sigma",
        str(noise_standard_deviation)
    ])
    if seed is not None:
        cargs.extend([
            "--seed",
            str(seed)
        ])
    if verbose_flag:
        cargs.append("--verbose")
    if help_flag:
        cargs.append("--help")
    ret = SystemnoiseOutputs(
        root=execution.output_file("."),
        output_signal_file=execution.output_file(pathlib.Path(output_signal).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SYSTEMNOISE_METADATA",
    "SystemnoiseOutputs",
    "systemnoise",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ABIDS_JSON_TOOL_PY_METADATA = Metadata(
    id="9cd5d1cbe0772f0f1c51d0bd811ef0336e43437f.boutiques",
    name="abids_json_tool.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AbidsJsonToolPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `abids_json_tool_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def abids_json_tool_py(
    input_file: InputPathType,
    prefix: str,
    del_json: str | None = None,
    values_stay_str: bool = False,
    runner: Runner | None = None,
) -> AbidsJsonToolPyOutputs:
    """
    This script helps to manipulate json files in various ways.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: One file to convert. Enter NULL with -add_json to create\
            new json file.
        prefix: Output file name.
        del_json: Remove attribute (KEY) from the -input json file.
        values_stay_str: Each numeric or str item gets saved as a str;\
            otherwise, guess at int and float.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AbidsJsonToolPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ABIDS_JSON_TOOL_PY_METADATA)
    cargs = []
    cargs.append("abids_json_tool.py")
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if del_json is not None:
        cargs.extend([
            "-del_json",
            del_json
        ])
    if values_stay_str:
        cargs.append("-values_stay_str")
    ret = AbidsJsonToolPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ABIDS_JSON_TOOL_PY_METADATA",
    "AbidsJsonToolPyOutputs",
    "abids_json_tool_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKEROT_METADATA = Metadata(
    id="228730131a9ac711780934f6fef814e8124671ad.boutiques",
    name="makerot",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MakerotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `makerot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    matrix_output: OutputPathType | None
    """Output file for the rotation matrix"""


def makerot(
    theta: float,
    axis: str | None = None,
    cov: InputPathType | None = None,
    center: str | None = None,
    output_file: InputPathType | None = None,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> MakerotOutputs:
    """
    Tool to create a rotation matrix for a given angle and axis of rotation.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        theta: Angle of rotation (in degrees).
        axis: Unnormalized axis vector (comma separated).
        cov: Image filename used for center of volume.
        center: Center of rotation in mm (comma separated).
        output_file: Output filename for matrix.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakerotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKEROT_METADATA)
    cargs = []
    cargs.append("makerot")
    if axis is not None:
        cargs.extend([
            "--axis",
            axis
        ])
    if cov is not None:
        cargs.extend([
            "--cov",
            execution.input_file(cov)
        ])
    if center is not None:
        cargs.extend([
            "--centre",
            center
        ])
    if output_file is not None:
        cargs.extend([
            "--out",
            execution.input_file(output_file)
        ])
    if verbose_flag:
        cargs.append("--verbose")
    if help_flag:
        cargs.append("--help")
    cargs.extend([
        "--theta",
        str(theta)
    ])
    ret = MakerotOutputs(
        root=execution.output_file("."),
        matrix_output=execution.output_file(pathlib.Path(output_file).name) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKEROT_METADATA",
    "MakerotOutputs",
    "makerot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

HISTO_REGISTER_BLOCK_METADATA = Metadata(
    id="a9ce2e4f5a3f5c4fa13464f62cf2766ed76dbba2.boutiques",
    name="histo_register_block",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class HistoRegisterBlockOutputs(typing.NamedTuple):
    """
    Output object returned when calling `histo_register_block(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aligned_output: OutputPathType
    """Aligned output file"""


def histo_register_block(
    seg_time1: InputPathType,
    seg_time2: InputPathType,
    transform1: InputPathType,
    transform2: InputPathType,
    output_file: str,
    out_like: InputPathType | None = None,
    invert_transform: bool = False,
    runner: Runner | None = None,
) -> HistoRegisterBlockOutputs:
    """
    A tool to align a histological slice with a block face image.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        seg_time1: Segmented image at time point 1.
        seg_time2: Segmented image at time point 2.
        transform1: Transformation file for time point 1.
        transform2: Transformation file for time point 2.
        output_file: Output file name for the aligned image.
        out_like: Set output volume parameters like the reference volume.
        invert_transform: Invert transform coordinates.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `HistoRegisterBlockOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(HISTO_REGISTER_BLOCK_METADATA)
    cargs = []
    cargs.append("histo_register_block")
    cargs.append(execution.input_file(seg_time1))
    cargs.append(execution.input_file(seg_time2))
    cargs.append(execution.input_file(transform1))
    cargs.append(execution.input_file(transform2))
    cargs.append(output_file)
    if out_like is not None:
        cargs.extend([
            "-out_like",
            execution.input_file(out_like)
        ])
    if invert_transform:
        cargs.append("-I")
    ret = HistoRegisterBlockOutputs(
        root=execution.output_file("."),
        aligned_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "HISTO_REGISTER_BLOCK_METADATA",
    "HistoRegisterBlockOutputs",
    "histo_register_block",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EDDY_QUAD_METADATA = Metadata(
    id="7f05140209b6ebad40342feebc8da9b92d964042.boutiques",
    name="eddy_quad",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class EddyQuadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `eddy_quad(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dir_qc: OutputPathType | None
    """Quality control data outputs"""


def eddy_quad(
    eddy_base: str,
    eddy_index: InputPathType,
    eddy_params: InputPathType,
    mask: InputPathType,
    bvals: InputPathType,
    bvecs: InputPathType | None = None,
    output_dir: str | None = None,
    field: InputPathType | None = None,
    slspec: InputPathType | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> EddyQuadOutputs:
    """
    QUality Assessment for DMRI.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        eddy_base: Basename (including path) specified when running EDDY.
        eddy_index: File containing indices for all volumes into acquisition\
            parameters.
        eddy_params: File containing acquisition parameters.
        mask: Binary mask file.
        bvals: b-values file.
        bvecs: b-vectors file - only used when <eddyBase>.eddy_residuals file\
            is present.
        output_dir: Output directory - default = '<eddyBase>.qc'.
        field: TOPUP estimated field (in Hz).
        slspec: Text file specifying slice/group acquisition.
        verbose: Display debug messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EddyQuadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EDDY_QUAD_METADATA)
    cargs = []
    cargs.append("eddy_quad")
    cargs.append(eddy_base)
    cargs.extend([
        "--eddyIdx",
        execution.input_file(eddy_index)
    ])
    cargs.extend([
        "--eddyParams",
        execution.input_file(eddy_params)
    ])
    cargs.extend([
        "--mask",
        execution.input_file(mask)
    ])
    cargs.extend([
        "--bvals",
        execution.input_file(bvals)
    ])
    if bvecs is not None:
        cargs.extend([
            "--bvecs",
            execution.input_file(bvecs)
        ])
    if output_dir is not None:
        cargs.extend([
            "--output-dir",
            output_dir
        ])
    if field is not None:
        cargs.extend([
            "--field",
            execution.input_file(field)
        ])
    if slspec is not None:
        cargs.extend([
            "--slspec",
            execution.input_file(slspec)
        ])
    if verbose:
        cargs.append("--verbose")
    ret = EddyQuadOutputs(
        root=execution.output_file("."),
        output_dir_qc=execution.output_file(output_dir) if (output_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EDDY_QUAD_METADATA",
    "EddyQuadOutputs",
    "eddy_quad",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__HELP_AFNI_METADATA = Metadata(
    id="87ebd1e4083856099825a6ef50fde5abb2dad615.boutiques",
    name="@help.AFNI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VHelpAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__help_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__help_afni(
    runner: Runner | None = None,
) -> VHelpAfniOutputs:
    """
    A script to retrieve and search AFNI's help page for all programs.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VHelpAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__HELP_AFNI_METADATA)
    cargs = []
    cargs.append("@help.AFNI")
    cargs.append("[OPTIONS]")
    ret = VHelpAfniOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VHelpAfniOutputs",
    "V__HELP_AFNI_METADATA",
    "v__help_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FLIP_4DFP_METADATA = Metadata(
    id="546744c4be37b8dfd459146df7ba1a0232818b0d.boutiques",
    name="flip_4dfp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Flip4dfpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `flip_4dfp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    flipped_image: OutputPathType | None
    """Flipped output 4dfp image"""


def flip_4dfp(
    input_image: InputPathType,
    output_image: str | None = None,
    flip_x: bool = False,
    flip_y: bool = False,
    flip_z: bool = False,
    endianness: typing.Literal["b", "l"] | None = None,
    runner: Runner | None = None,
) -> Flip4dfpOutputs:
    """
    A tool to flip 4dfp images along specified axes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: Input 4dfp image file.
        output_image: Output 4dfp image file. Default is input image root with\
            '_flip' suffix.
        flip_x: Flip along x-axis.
        flip_y: Flip along y-axis.
        flip_z: Flip along z-axis.
        endianness: Specify output endianness: 'b' for big endian, 'l' for\
            little endian. Default is input endianness.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Flip4dfpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FLIP_4DFP_METADATA)
    cargs = []
    cargs.append("flip_4dfp")
    cargs.append(execution.input_file(input_image))
    if output_image is not None:
        cargs.append(output_image)
    if flip_x:
        cargs.append("-x")
    if flip_y:
        cargs.append("-y")
    if flip_z:
        cargs.append("-z")
    if endianness is not None:
        cargs.extend([
            "-@",
            endianness
        ])
    ret = Flip4dfpOutputs(
        root=execution.output_file("."),
        flipped_image=execution.output_file(output_image + ".4dfp.img") if (output_image is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FLIP_4DFP_METADATA",
    "Flip4dfpOutputs",
    "flip_4dfp",
]
